@@ -139,7 +139,6 @@ public final class ConfigKeys {
 		public static final String BCFG_MISSING_FILE_DOWNLOAD_RESTART = "Missing File Download Restart Enable";
 		public static final String BCFG_SKIP_COMP_DL_FILE_CHECKS = "Skip Complete Download File Checks";
 		public static final String ICFG_MISSING_FILE_DOWNLOAD_RESTART_MINS = "Missing File Download Restart Period";
-		public static final String BCFG_USE_RESUME = "Use Resume";
 		public static final String ICFG_SAVE_RESUME_INTERVAL = "Save Resume Interval";
 		public static final String BCFG_ON_RESUME_RECHECK_ALL = "On Resume Recheck All";
 		public static final String BCFG_FILE_SAVE_PEERS_ENABLE = "File.save.peers.enable";
@@ -291,6 +290,7 @@ public final class ConfigKeys {
 		public static final String BCFG_RESUME_DOWNLOADS_ON_START = "Resume Downloads On Start";
 		public static final String BCFG_STOP_TRIGGERS_AUTO_RESET = "Stop Triggers Auto Reset";
 		public static final String BCFG_PROMPT_TO_ABORT_SHUTDOWN = "Prompt To Abort Shutdown";
+		public static final String ICFG_STOP_FORCE_TERMINATE_AFTER = "Force Terminate After Mins";
 		public static final String ICFG_AUTO_RESTART_WHEN_IDLE = "Auto Restart When Idle";
 		public static final String SCFG_ON_DOWNLOADING_COMPLETE_DO = "On Downloading Complete Do";
 		public static final String SCFG_ON_DOWNLOADING_COMPLETE_SCRIPT = "On Downloading Complete Script";
