@@ -222,7 +222,6 @@ public class ConfigurationDefaults {
     def.put( "Max LAN Download Speed KBs", ZERO );
     def.put( "Max LAN Upload Speed KBs", ZERO );
 
-    def.put("Use Resume", TRUE);
     def.put("On Resume Recheck All", FALSE);
     def.put("Save Resume Interval", new Long(5));
     def.put("Check Pieces on Completion", TRUE);
@@ -284,6 +283,7 @@ public class ConfigurationDefaults {
     def.put("On Downloading Complete Do", "Nothing" );
     def.put("On Seeding Complete Do", "Nothing" );
     def.put("Stop Triggers Auto Reset", TRUE );
+    def.put( ConfigKeys.StartupShutdown.ICFG_STOP_FORCE_TERMINATE_AFTER, 2 );
     def.put("Prompt To Abort Shutdown", TRUE );
     def.put("Prevent Sleep Downloading", TRUE );
     def.put("Prevent Sleep FP Seeding", FALSE );
