@@ -65,6 +65,8 @@ DiskManagerFileInfoImpl
 
   protected boolean 	skipped_internal 	= false;
 
+  private volatile Boolean	skipping;
+  
   private String last_error = null;
   
   private volatile CopyOnWriteList<DiskManagerFileInfoListener>	listeners;	// save mem and allocate if needed later
@@ -98,6 +100,15 @@ DiskManagerFileInfoImpl
   	}
   }
 
+	protected void
+	load(
+		int		_priority,
+		boolean	_skipped )
+	{
+		priority				= _priority;
+		skipped_internal		= _skipped;
+	}
+	
   	@Override
 	  public String
   	getCacheFileOwnerName()
@@ -263,6 +274,8 @@ DiskManagerFileInfoImpl
 	setLinkAtomic(
 		File	link_destination )
 	{
+		last_error = "download must be stopped";
+		
 		Debug.out( "setLink: download must be stopped" );
 
 		return( false );
@@ -274,6 +287,8 @@ DiskManagerFileInfoImpl
 		File						link_destination,
 		FileUtil.ProgressListener	pl )
 	{
+		last_error = "download must be stopped";
+		
 		Debug.out( "setLink: download must be stopped" );
 
 		return( false );
@@ -387,34 +402,45 @@ DiskManagerFileInfoImpl
    * @param skipped
    */
   @Override
-  public void setSkipped(boolean _skipped) {
+  public void setSkipped(boolean skipped) {
 
-	int	existing_st = getStorageType();
-
-	  // currently a non-skipped file must be linear
-
-	if ( !_skipped && existing_st == ST_COMPACT ){
-		if ( !setStorageType( ST_LINEAR )){
-			return;
+	  try{
+		skipping = skipped;
+		  
+		int	existing_st = getStorageType();
+	
+		  // currently a non-skipped file must be linear
+	
+		if ( !skipped && existing_st == ST_COMPACT ){
+			if ( !setStorageType( ST_LINEAR )){
+				return;
+			}
 		}
-	}
-
-	if ( !_skipped && existing_st == ST_REORDER_COMPACT ){
-		if ( !setStorageType( ST_REORDER )){
-			return;
+	
+		if ( !skipped && existing_st == ST_REORDER_COMPACT ){
+			if ( !setStorageType( ST_REORDER )){
+				return;
+			}
 		}
-	}
-
-	setSkippedInternal( _skipped );
-	diskManager.skippedFileSetChanged( this );
-	if(!_skipped)
-	{
+	
+		setSkippedInternal( skipped );
+		
+		diskManager.skippedFileSetChanged( this );
+			
 		boolean[] toCheck = new boolean[diskManager.getFileSet().nbFiles()];
+			
 		toCheck[file_index] = true;
-		DiskManagerUtil.doFileExistenceChecks(diskManager.getFileSet(), toCheck, diskManager.getDownloadState().getDownloadManager(), true);
-	}
+			
+		DiskManagerUtil.doFileExistenceChecksAfterSkipChange(diskManager.getFileSet(), toCheck, skipped, diskManager.getDownloadState().getDownloadManager());
+	  }finally{
+		  skipping = null;
+	  }
   }
 
+  @Override
+  public Boolean isSkipping(){
+	  return( skipping );
+  }
 	protected void
 	setSkippedInternal(
 		boolean	_skipped )
