@@ -68,7 +68,7 @@ RDResumeHandler
 	public static final byte		PIECE_RECHECK_REQUIRED	= 2;
 	public static final byte		PIECE_STARTED			= 3;
 
-	static boolean	use_fast_resume;
+	// static boolean	use_fast_resume = true;	// made this permanent, setting it false really borks things
 	static boolean	use_fast_resume_recheck_all;
 	static boolean	skip_comp_dl_file_checks;
 
@@ -76,7 +76,6 @@ RDResumeHandler
 
 		COConfigurationManager.addAndFireParameterListeners(
 			new String[]{
-					"Use Resume",
 					"On Resume Recheck All",
 					ConfigKeys.File.BCFG_SKIP_COMP_DL_FILE_CHECKS },
 			new ParameterListener() {
@@ -85,7 +84,6 @@ RDResumeHandler
 				parameterChanged(
 					String  str )
 	    	    {
-	    	    	use_fast_resume				= COConfigurationManager.getBooleanParameter("Use Resume");
 	    	    	use_fast_resume_recheck_all	= COConfigurationManager.getBooleanParameter("On Resume Recheck All");
 	    	    	skip_comp_dl_file_checks	= COConfigurationManager.getBooleanParameter(ConfigKeys.File.BCFG_SKIP_COMP_DL_FILE_CHECKS);
 	    	    }
@@ -181,7 +179,7 @@ RDResumeHandler
 			try{
 				check_in_progress	= true;
 
-				boolean resumeEnabled = use_fast_resume;
+				boolean resumeEnabled = true;	// changed this to always be enabled as disabling it leads to crap
 
 					//disable fast resume if a new file was created
 
@@ -206,9 +204,7 @@ RDResumeHandler
 					file_sizes = null;
 					
 				}else{
-					
-					DiskManagerFileInfo[]	files = disk_manager.getFiles();
-					
+										
 					file_sizes = new HashMap<>();
 				}
 
@@ -977,6 +973,7 @@ RDResumeHandler
 
 		DiskManagerFileInfo[]	files = disk_manager.getFiles();
 
+		/*
 		if ( !use_fast_resume ){
 
 				// flush cache even if resume disable as this is a good point to ensure that data
@@ -989,7 +986,8 @@ RDResumeHandler
 
 			return;
 		}
-
+		*/
+		
 		boolean	was_complete = isTorrentResumeDataComplete( disk_manager.getDownloadManager().getDownloadState());
 
 		if ( was_complete && check_interrupted ){
@@ -1413,6 +1411,28 @@ RDResumeHandler
 		clearResumeDataSupport( download_manager, file, true, false );
 	}
 
+	public static void
+	setTorrentResumeTotallyIncomplete(
+		DownloadManagerState	download_manager_state )
+	{
+		TOTorrent	torrent = download_manager_state.getTorrent();
+		
+		long	piece_count = torrent.getNumberOfPieces();
+
+		byte[] resume_pieces = new byte[(int)piece_count];
+
+		Arrays.fill( resume_pieces, PIECE_NOT_DONE );
+		
+		Map resumeMap = new HashMap();
+
+		resumeMap.put( "resume data", resume_pieces);
+		
+		resumeMap.put("valid", new Long(1));
+
+		saveResumeData(download_manager_state,resumeMap);
+	}
+
+	
 	public static void
 	setTorrentResumeDataNearlyComplete(
 		DownloadManagerState	download_manager_state )
@@ -1529,26 +1549,29 @@ RDResumeHandler
 				}
 				
 				Map		partialPieces	= (Map)resume_data.get("blocks");
-						
-				Iterator iter = partialPieces.entrySet().iterator();
-	
-				while (iter.hasNext()) {
-	
-					Map.Entry key = (Map.Entry)iter.next();
-	
-					int pieceNumber = Integer.parseInt((String)key.getKey());
-	
-					DiskManagerPiece	dm_piece = pieces[ pieceNumber ];
-	
-					if ( !dm_piece.isDone()){
-	
-						List blocks = (List)partialPieces.get(key.getKey());
-	
-						Iterator iterBlock = blocks.iterator();
-	
-						while (iterBlock.hasNext()) {
-	
-							dm_piece.setWritten(((Long)iterBlock.next()).intValue());
+					
+				if ( partialPieces != null ){
+					
+					Iterator iter = partialPieces.entrySet().iterator();
+		
+					while (iter.hasNext()) {
+		
+						Map.Entry key = (Map.Entry)iter.next();
+		
+						int pieceNumber = Integer.parseInt((String)key.getKey());
+		
+						DiskManagerPiece	dm_piece = pieces[ pieceNumber ];
+		
+						if ( !dm_piece.isDone()){
+		
+							List blocks = (List)partialPieces.get(key.getKey());
+		
+							Iterator iterBlock = blocks.iterator();
+		
+							while (iterBlock.hasNext()) {
+		
+								dm_piece.setWritten(((Long)iterBlock.next()).intValue());
+							}
 						}
 					}
 				}
