@@ -40,6 +40,11 @@ import com.biglybt.core.history.DownloadHistory;
 import com.biglybt.core.history.DownloadHistoryEvent;
 import com.biglybt.core.history.DownloadHistoryListener;
 import com.biglybt.core.history.DownloadHistoryManager;
+import com.biglybt.core.tag.Tag;
+import com.biglybt.core.tag.TagManager;
+import com.biglybt.core.tag.TagManagerFactory;
+import com.biglybt.core.tag.TagType;
+import com.biglybt.core.tag.TagUtils;
 import com.biglybt.core.torrent.TOTorrent;
 import com.biglybt.core.util.*;
 
@@ -59,8 +64,12 @@ DownloadHistoryManagerImpl
 	private static final int UPDATE_TYPE_DEAD	= 0x10;
 	private static final int UPDATE_TYPE_BOTH	= UPDATE_TYPE_ACTIVE | UPDATE_TYPE_DEAD;
 
+	private static final Object	TAG_CACHE_KEY = new Object();
+	
 	private final Core core;
 
+	private static final TagManager	tag_manager = TagManagerFactory.getTagManager();
+	
 	private final ListenerManager<DownloadHistoryListener>	listeners =
 		ListenerManager.createAsyncManager(
 			"DHM",
@@ -196,7 +205,11 @@ DownloadHistoryManagerImpl
 
 											dh.setHistoryReference( dead_history );
 
-											dh.setRemoveTime( SystemTime.getCurrentTime());
+											List<Tag> tags = (List<Tag>)dm.getUserData( TAG_CACHE_KEY );
+											
+											tags = TagUtils.sortTags( tags );
+											
+											dh.setRemoved( tags );
 
 											historyUpdated( dh, DownloadHistoryEvent.DHE_HISTORY_MODIFIED, UPDATE_TYPE_BOTH );
 										}
@@ -204,6 +217,20 @@ DownloadHistoryManagerImpl
 								}
 							}, false );
 
+						global_manager.addDownloadWillBeRemovedListener((dm,b1,b2)->{
+							
+							try{
+								List<Tag>	tags = tag_manager.getTagsForTaggable( TagType.TT_DOWNLOAD_MANUAL, dm );
+
+								dm.setUserData( TAG_CACHE_KEY, tags );
+							
+							}catch( Throwable e ){
+								
+								Debug.out( e );;
+							}
+							
+						});
+						
 						DownloadManagerFactory.addGlobalDownloadListener(
 							new DownloadManagerAdapter()
 							{
@@ -267,6 +294,38 @@ DownloadHistoryManagerImpl
 								}
 							}, DownloadManagerState.AT_CANONICAL_SD_DMAP, DownloadManagerStateAttributeListener.WRITTEN );
 
+						DownloadManagerStateFactory.addGlobalListener(
+								new DownloadManagerStateAttributeListener() {
+
+									@Override
+									public void
+									attributeEventOccurred(
+										DownloadManager 	dm,
+										String 				attribute,
+										int 				event_type )
+									{
+										synchronized( lock ){
+
+											if ( !( enabled && isMonitored(dm))){
+
+												return;
+											}
+
+											long uid = getUID( dm );
+
+											DownloadHistoryImpl dh = getActiveHistory().get( uid );
+
+											if ( dh != null ){
+
+												if ( dh.updateName( dm )){
+
+													historyUpdated( dh, DownloadHistoryEvent.DHE_HISTORY_MODIFIED, UPDATE_TYPE_ACTIVE );
+												}
+											}
+										}
+									}
+								}, DownloadManagerState.AT_DISPLAY_NAME, DownloadManagerStateAttributeListener.WRITTEN );
+
 						if ( enabled ){
 
 							if ( !FileUtil.resilientConfigFileExists( CONFIG_ACTIVE_FILE )){
@@ -863,16 +922,21 @@ DownloadHistoryManagerImpl
 		}
 	}
 
+	private static String[] NO_TAGS = {};
+	
 	private class
 	DownloadHistoryImpl
 		implements DownloadHistory
 	{
 		private final long 		uid;
 		private final byte[]	hash;
+		private final byte[]	hash_v2;
 		private final long		size;
-		private String			name 			= "test test test";
-		private String			save_location	= "somewhere or other";
-		private long			add_time		= -1;
+		private final long		add_time;
+		
+		private String			name;
+		private String			save_location;
+		private String[]		tags			= NO_TAGS;
 		private long			complete_time	= -1;
 		private long			remove_time		= -1;
 
@@ -886,21 +950,30 @@ DownloadHistoryManagerImpl
 
 			uid		= DownloadHistoryManagerImpl.getUID( dm );
 
-			byte[]	h = null;
-
+			byte[]	h1 	= null;
+			byte[]	h2 	= null;
+			
 			TOTorrent torrent = dm.getTorrent();
 
 			if ( torrent != null ){
 
 				try{
-					h = torrent.getHash();
+					h1 	= torrent.getFullHash( TOTorrent.TT_V1 );
 
+					if ( h1 == null ){
+						
+						h1 = torrent.getHash();
+					}
+					
+					h2 	= torrent.getFullHash( TOTorrent.TT_V2 );
+					
 				}catch( Throwable e ){
 				}
 			}
 
-			hash	= h;
-
+			hash	= h1;
+			hash_v2	= h2;
+			
 			name	= dm.getDisplayName();
 
 			size	= dm.getSize();
@@ -911,6 +984,8 @@ DownloadHistoryManagerImpl
 
 			add_time 		= dms.getLongParameter( DownloadManagerState.PARAM_DOWNLOAD_ADDED_TIME );
 
+				// tags only populated on removal
+			
 			updateCompleteTime( dms );
 		}
 
@@ -925,9 +1000,10 @@ DownloadHistoryManagerImpl
 			try{
 				uid		= (Long)map.get( "u" );
 				hash	= (byte[])map.get("h");
-
-				name 			= new String((byte[])map.get( "n"), "UTF-8" );
-				save_location 	= new String((byte[])map.get( "s"), "UTF-8" );
+				hash_v2	= (byte[])map.get( "v" );
+				
+				name 			= new String((byte[])map.get( "n"), Constants.UTF_8 );
+				save_location 	= new String((byte[])map.get( "s"), Constants.UTF_8 );
 
 				Long l_size		= (Long)map.get( "z" );
 
@@ -937,10 +1013,17 @@ DownloadHistoryManagerImpl
 				complete_time 	= (Long)map.get( "c" );
 				remove_time 	= (Long)map.get( "r" );
 
-			}catch( IOException e ){
-
-				throw( e );
-
+				List<byte[]> l_tags = (List<byte[]>)map.get( "t" );
+				
+				if ( l_tags != null ){
+					
+					tags = new String[l_tags.size()];
+					
+					for ( int i=0;i<l_tags.size();i++){
+						
+						tags[i] = new String( l_tags.get(i), Constants.UTF_8 );
+					}
+				}
 			}catch( Throwable e ){
 
 				throw( new IOException( "History decode failed: " + Debug.getNestedExceptionMessage( e )));
@@ -963,13 +1046,30 @@ DownloadHistoryManagerImpl
 
 			map.put( "u", uid );
 			map.put( "h", hash );
-			map.put( "n", name.getBytes( "UTF-8" ));
+			
+			if ( hash_v2 != null ){
+				map.put( "v", hash_v2 );
+			}
+			
+			map.put( "n", name.getBytes( Constants.UTF_8 ));
 			map.put( "z", size );
-			map.put( "s", save_location.getBytes( "UTF-8" ));
+			map.put( "s", save_location.getBytes( Constants.UTF_8 ));
 			map.put( "a", add_time );
 			map.put( "c", complete_time );
 			map.put( "r", remove_time );
 
+			if ( tags != null && tags.length > 0 ){
+				
+				List<byte[]>	l_tags = new ArrayList<>();
+				
+				for ( String tag: tags ){
+					
+					l_tags.add( tag.getBytes( Constants.UTF_8 ));
+				}
+				
+				map.put( "t", l_tags );
+			}
+			
 			return( map );
 		}
 
@@ -1012,6 +1112,24 @@ DownloadHistoryManagerImpl
 				return( false );
 			}
 		}
+		
+		boolean
+		updateName(
+			DownloadManager		dm )
+		{
+			String name2 = dm.getDisplayName();
+			
+			if ( !name.equals( name2 )){
+
+				name = name2;
+
+				return( true );
+
+			}else{
+
+				return( false );
+			}
+		}
 
 		@Override
 		public long
@@ -1026,6 +1144,14 @@ DownloadHistoryManagerImpl
 		{
 			return( hash );
 		}
+		
+		@Override
+		public byte[]
+		getTorrentV2Hash()
+		{
+			return( hash_v2 );
+		}
+		
 
 		@Override
 		public String
@@ -1062,11 +1188,28 @@ DownloadHistoryManagerImpl
 			return( complete_time );
 		}
 
-		void
-		setRemoveTime(
-			long		time )
+		@Override
+		public String[] 
+		getTags()
 		{
-			remove_time	= time;
+			return( tags );
+		}
+		
+		void
+		setRemoved(
+			List<Tag>	removal_tags  )
+		{
+			remove_time	= SystemTime.getCurrentTime();
+			
+			if ( removal_tags != null && !removal_tags.isEmpty()){
+				
+				tags = new String[removal_tags.size()];
+					
+				for ( int i=0; i<removal_tags.size(); i++ ){
+						
+					tags[i] = removal_tags.get(i).getTagName( true );
+				}
+			}
 		}
 
 		@Override
