@@ -1694,6 +1694,10 @@ public class PeerManager implements CoreStatsProvider {
 			public int
 			getPartitionID(){ log(); return( 0 ); }
 
+			public void
+			setMaskDownloadCompletion(
+				boolean	mask ){ log(); }
+			
 			public void
 			removeAllPeers(
 					String		reason ){log(); }
