@@ -23,11 +23,11 @@ package com.biglybt.core.subs.impl;
 import java.lang.ref.WeakReference;
 import java.util.Date;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
 import com.biglybt.core.config.COConfigurationManager;
-import com.biglybt.core.metasearch.FilterableResult;
 import com.biglybt.core.metasearch.Result;
 import com.biglybt.core.subs.SubscriptionResult;
 import com.biglybt.core.util.*;
@@ -59,7 +59,8 @@ SubscriptionResultImpl
 	private byte[]		key2;
 	private boolean		read;
 	private boolean		deleted;
-
+	private int			deleted_last_seen_day;
+	
 	private String		result_json;
 
 	private WeakReference<Map<Integer,Object>>	props_ref = null;
@@ -128,6 +129,15 @@ SubscriptionResultImpl
 
 			deleted	= true;
 
+			Number l_dls = (Number)map.get( "dls" );
+			
+			if ( l_dls != null ){
+				
+				deleted_last_seen_day = l_dls.intValue();
+			}else{
+				
+				deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+			}
 		}else{
 
 			try{
@@ -146,6 +156,8 @@ SubscriptionResultImpl
 	{
 		if ( deleted ){
 
+			deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+			
 			return( false );
 		}
 
@@ -165,13 +177,61 @@ SubscriptionResultImpl
 
 		Map	other_json_map = null;
 		
+		boolean	other_json_map_updated	= false;
+		
 		if ( my_tf != null ){
 
 			other_json_map 	= JSONUtils.decodeJSON( other_json_str );
 
 			other_json_map.put( "tf", my_tf );
+			
+			other_json_map_updated = true;
+		}
+			
+		List<String> my_tags 	= (List<String>)my_json_map.get( "tgs" );
 
-			other_json_str = JSONUtils.encodeToJSON( other_json_map );
+		if ( my_tags != null && !my_tags.isEmpty()){
+
+			boolean other_has_tgs = other_json_str.contains("\"tgs\"" );
+		
+			if ( other_has_tgs ){
+							
+				boolean updated = false;
+
+				if ( other_json_map == null ){
+					
+					other_json_map 	= JSONUtils.decodeJSON( other_json_str );
+				}
+				
+				List<String> other_tags = (List<String>)other_json_map.get( "tgs" );
+
+				for ( String t: my_tags ){
+					
+					if ( !other_tags.contains( t )){
+						
+						other_tags.add( t );
+						
+						updated = true;
+					}
+				}
+				
+				if ( updated ){
+					
+					other_json_map.put( "tgs", other_tags );
+					
+					other_json_map_updated = true;
+				}
+			}else{
+									
+				if ( other_json_map == null ){
+					
+					other_json_map 	= JSONUtils.decodeJSON( other_json_str );
+				}
+				
+				other_json_map.put( "tgs", my_tags );
+				
+				other_json_map_updated = true;
+			}
 		}
 		
 			// keep oldest pub date
@@ -209,11 +269,16 @@ SubscriptionResultImpl
 			if ( keep ){
 				
 				other_json_map.put( "ts", my_ts );
-
-				other_json_str = JSONUtils.encodeToJSON( other_json_map );
+				
+				other_json_map_updated = true;
 			}
 		}
 		
+		if ( other_json_map_updated ){
+			
+			other_json_str = JSONUtils.encodeToJSON( other_json_map );
+		}
+		
 		if ( my_json_str.equals( other_json_str )){
 
 			return( false );
@@ -286,6 +351,8 @@ SubscriptionResultImpl
 
 			deleted	= true;
 
+			deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+
 			history.updateResult( this );
 		}
 	}
@@ -303,6 +370,12 @@ SubscriptionResultImpl
 		return( deleted );
 	}
 
+	protected int
+	getDeletedLastSeen()
+	{
+		return( deleted_last_seen_day );
+	}
+	
 	protected Map
 	toBEncodedMap()
 	{
@@ -320,6 +393,13 @@ SubscriptionResultImpl
 
 			map.put( "deleted", new Long(1));
 
+			if ( deleted_last_seen_day == 0 ){
+				
+				deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+			}
+			
+			map.put( "dls", deleted_last_seen_day );
+			
 		}else{
 
 			try{
@@ -514,7 +594,14 @@ SubscriptionResultImpl
 
 				result.put( SearchResult.PR_CATEGORY, category );
 			}
-
+			
+			List<String> tags = (List<String>)map.get( "tgs" );
+			
+			if ( tags != null && !tags.isEmpty()){
+				
+				result.put( SearchResult.PR_TAGS, tags.toArray( new String[tags.size()]));
+			}
+			
 			String contentType = (String)map.get( "ct" );
 
 			if ( contentType != null ){
