@@ -53,6 +53,7 @@ SubscriptionResultFilterable
 	private String				votes_comments;
 	private int					rank;
 	private long				asset_date;
+	private String[]			tags;
 
 	private LightHashMap<Object,Object>	user_data;
 
@@ -102,7 +103,7 @@ SubscriptionResultFilterable
 		details_link = (String)properties.get( SearchResult.PR_DETAILS_LINK );
 
 		category = (String)properties.get( SearchResult.PR_CATEGORY );
-
+		
 		Date	ad = (Date)properties.get( SearchResult.PR_ASSET_DATE );
 		
 		if ( ad != null ){
@@ -138,6 +139,8 @@ SubscriptionResultFilterable
 			}
 		}
 
+		tags = (String[])properties.get( SearchResult.PR_TAGS );
+
 		long seeds 		= (Long)properties.get( SearchResult.PR_SEED_COUNT );
 		long leechers 	= (Long)properties.get( SearchResult.PR_LEECHER_COUNT );
 
@@ -298,6 +301,13 @@ SubscriptionResultFilterable
 		return( category );
 	}
 
+	@Override
+	public String[] 
+	getTags()
+	{
+		return( tags );
+	}
+	
 	@Override
 	public long
 	getTime()
