@@ -144,6 +144,12 @@ TagTypeBase
 		return( manager );
 	}
 
+	protected TaggableResolver
+	getResolver()
+	{
+		return( manager.getResolver( tag_type ));
+	}
+	
 	protected Taggable
 	resolveTaggable(
 		String		id )
@@ -700,6 +706,7 @@ TagTypeBase
  		
  		private boolean		exclusive;
  		private File		ass_root;
+ 		private int[]		group_colour;
  		
  		private CopyOnWriteList<Tag>	tags = new CopyOnWriteList<>();
  		
@@ -730,6 +737,18 @@ TagTypeBase
  				
  				ass_root = FileUtil.newFile( ar );
  			}
+ 			
+ 			List<Number>	gc = (List<Number>)map.get( "gc" );
+ 			
+ 			if ( gc != null ){
+ 				
+ 				group_colour = new int[gc.size()];
+ 				
+ 				for ( int i=0;i<group_colour.length;i++){
+ 					
+ 					group_colour[i] = gc.get(i).intValue();
+ 				}
+ 			}
  		}
  		
  		protected Map<String,Object>
@@ -747,6 +766,16 @@ TagTypeBase
  				map.put( "ar", ass_root.getAbsolutePath());
  			}
  			
+ 			if ( group_colour != null ){
+ 				
+ 				List<Integer> list = new ArrayList<Integer>( group_colour.length );
+ 				for ( int i: group_colour ){
+ 					list.add(i);
+ 				}
+ 				
+ 				map.put( "gc", list );
+ 			}
+ 			
  			return( map );
  		}
  		
@@ -771,6 +800,8 @@ TagTypeBase
  				exclusive = b;
  				
  				manager.tagGroupUpdated( TagTypeBase.this, this );
+ 				
+ 				groupChanged();
  			}
  		}
  		
@@ -807,9 +838,38 @@ TagTypeBase
  				}
  				
  				manager.tagGroupUpdated( TagTypeBase.this, this );
+ 				
+ 				groupChanged();
  			}
  		}
  		
+ 		@Override
+ 		public int[] 
+ 		getColor()
+ 		{
+ 			return( group_colour );
+ 		}
+ 		
+ 		@Override
+ 		public void 
+ 		setColor(
+ 			int[] rgb)
+ 		{
+ 			group_colour = rgb;
+ 			
+ 			for ( Tag tag: tags ){
+ 				
+ 				if ( tag.isColorDefault()){
+ 				
+ 					tag.setColor( rgb );
+ 				}
+ 			}
+ 			
+ 			manager.tagGroupUpdated( TagTypeBase.this, this );
+ 			
+ 			groupChanged();
+ 		}
+ 		
  		@Override
  		public TagType 
  		getTagType()
@@ -844,10 +904,18 @@ TagTypeBase
 	 				}
 	 			}
 	 			
+	 			if ( tag.isColorDefault()){
+	 				
+	 				if ( group_colour != null ){
+	 					
+	 					tag.setColor( group_colour );
+	 				}
+	 			}
+	 			
 	 			for( TagGroupListener l: listeners ){
 	 				
 	 				try{
-	 					l.tagAdded(tag);
+	 					l.tagAdded(this,tag);
 	 					
 	 				}catch( Throwable e ){
 	 					
@@ -868,7 +936,7 @@ TagTypeBase
 	 			for( TagGroupListener l: listeners ){
 	 				
 	 				try{
-	 					l.tagRemoved(tag);
+	 					l.tagRemoved(this,tag);
 	 					
 	 				}catch( Throwable e ){
 	 					
@@ -877,7 +945,20 @@ TagTypeBase
 	 			}
  			}
  		}
- 		
+ 		private void
+ 		groupChanged()
+ 		{
+ 			for( TagGroupListener l: listeners ){
+ 				
+ 				try{
+ 					l.groupChanged(this);
+ 					
+ 				}catch( Throwable e ){
+ 					
+ 					Debug.out( e );
+ 				}
+ 			}
+ 		}
  		
  		public void
  		addListener(
@@ -890,7 +971,7 @@ TagTypeBase
  				
  				for ( Tag t: tags ){
  					
- 					l.tagAdded( t );
+ 					l.tagAdded( this, t );
  				}
  			}
  		}
@@ -909,6 +990,11 @@ TagTypeBase
  		String	old_name,
  		String	new_name )
  	{
+ 		if ( old_name == new_name || ( old_name != null && old_name.equals( new_name ))){
+ 			
+ 			return;
+ 		}
+ 		
  		synchronized( this ){
  			
  			if ( old_name != null ){
@@ -928,11 +1014,11 @@ TagTypeBase
  				if ( tg == null ){
  					
  					tg = new TagGroupImpl( new_name );
- 					
- 					manager.tagGroupCreated( this, tg );
- 					
+ 										
  					tag_groups.put( new_name, tg );
- 				}
+
+ 					manager.tagGroupCreated( this, tg );
+  				}
  				
  				tg.addTag( tag );
  			}
@@ -956,11 +1042,11 @@ TagTypeBase
  				
  				if ( result == null ){
  					
- 					result = new TagGroupImpl( name );
- 					
- 					manager.tagGroupCreated( this, result );
+ 					result = new TagGroupImpl( name ); 					
  					
  					tag_groups.put( name, result );
+
+ 					manager.tagGroupCreated( this, result );
  				}
  				
  				return( result );
