@@ -38,6 +38,7 @@ import com.biglybt.core.tag.Tag;
 import com.biglybt.core.tag.TagManager;
 import com.biglybt.core.tag.TagManagerFactory;
 import com.biglybt.core.tag.TagType;
+import com.biglybt.core.tag.TagUtils;
 import com.biglybt.core.torrent.*;
 import com.biglybt.core.util.*;
 import com.biglybt.plugin.I2PHelpers;
@@ -63,7 +64,7 @@ public class TorrentOpenOptions
 	public final static int QUEUELOCATION_TOP = 0;
 
 	public final static String[] STARTMODE_KEYS = {
-			"OpenTorrentWindow.startMode.queued",
+			"OpenTorrentWindow.startMode.queuedstarted",
 			"OpenTorrentWindow.startMode.stopped",
 			"ManagerItem.paused",
 			"OpenTorrentWindow.startMode.forceStarted",
@@ -140,8 +141,9 @@ public class TorrentOpenOptions
 
 	private String 				userComment;
 	
-	private List<Tag>			initialTags = new ArrayList<>();
-	private Set<Tag>			autoTags	= new HashSet<>();
+	private List<Tag>			initialTags 	= new ArrayList<>();
+	private Set<Tag>			autoTags		= new HashSet<>();
+	private List<String>		swarmTags		= new ArrayList<>();
 	
 	private boolean				autoTaggingApplied;
 	
@@ -560,6 +562,18 @@ public class TorrentOpenOptions
 		initialTags = tags;
 	}
 
+	public void
+	addSwarmTag(
+		String	tag )
+	{
+		if ( TagUtils.isInternalTagName( tag )){
+			return;
+		}
+		if ( !swarmTags.contains(tag)){
+			swarmTags.add( tag );
+		}
+	}
+	
 	public Map<String,Object>
 	getInitialMetadata()
 	{
@@ -1933,6 +1947,11 @@ public class TorrentOpenOptions
 							}
 						}
 
+						if ( !swarmTags.isEmpty()){
+							
+							dms.setListAttribute( DownloadManagerState.AT_SWARM_TAGS, swarmTags.toArray(new String[0]));
+						}
+						
 						if ( getSequentialDownload()) {
 
 							dms.setFlag( DownloadManagerState.FLAG_SEQUENTIAL_DOWNLOAD, true );
