@@ -20,7 +20,6 @@ package com.biglybt.core.util;
 import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.nio.charset.Charset;
-import java.security.AccessControlException;
 import java.util.Locale;
 import java.util.StringTokenizer;
 import java.util.TimeZone;
@@ -112,14 +111,7 @@ Constants
 			}
 		}catch( Throwable e ){
 
-			// can happen in applet
-
-			if ( e instanceof AccessControlException ){
-
-			}else{
-
-				e.printStackTrace();
-			}
+			e.printStackTrace();
 		}
 	}
 
@@ -150,11 +142,11 @@ Constants
 	public static final String BIGLY_PEER_ID						= "BI";
 
 	
-	public static final String BIGLYBT_VERSION  = "2.9.0.0";
+	public static final String BIGLYBT_VERSION  = "3.0.0.0";
 	
 	//public static final String BUILD_VERSION  = "@build.version@";   //Ant replace - believed dead
 	public static final String SUBVERSION		= "";
-	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "2900" + "-").getBytes();  //MUST be 8 chars long!
+	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "3000" + "-").getBytes();  //MUST be 8 chars long!
 
 	private static final boolean FORCE_NON_CVS = System.getProperty( "az.force.noncvs", "0" ).equals( "1" );
 
