@@ -133,6 +133,7 @@ PRUDPPacketHandlerImpl
 
 	private InetAddress				default_bind_ip;
 	private InetAddress				explicit_bind_ip;
+	private boolean					explicit_bind_ip_ad;
 
 	private volatile InetAddress				current_bind_ip;
 	private volatile InetAddress				target_bind_ip;
@@ -187,11 +188,12 @@ PRUDPPacketHandlerImpl
 					perform(
 						TimerEvent	event )
 					{
-						if ( destroyed && f_ev[0] != null ){
+						boolean jobDone = checkTimeouts();
+						
+						if ( jobDone && f_ev[0] != null ){
 
 							f_ev[0].cancel();
 						}
-						checkTimeouts();
 					}
 				});
 
@@ -376,13 +378,15 @@ PRUDPPacketHandlerImpl
 	@Override
 	public void
 	setExplicitBindAddress(
-		InetAddress	address )
+		InetAddress	address,
+		boolean		autoDelegate )
 	{
 		try{
 			bind_address_mon.enter();
 
 			explicit_bind_ip	= address;
-
+			explicit_bind_ip_ad	= autoDelegate;
+			
 			calcBind();
 
 		}finally{
@@ -418,43 +422,79 @@ PRUDPPacketHandlerImpl
 	{
 		if ( explicit_bind_ip != null ){
 
-			if(altProtocolDelegate != null)
-			{
-				altProtocolDelegate.destroy();
-				altProtocolDelegate = null;
+			if ( explicit_bind_ip_ad ){
+				
+				InetAddress altAddress = null;
+				NetworkAdmin adm = NetworkAdmin.getSingleton();
+				
+				try{
+					if (explicit_bind_ip instanceof Inet6Address && !explicit_bind_ip.isAnyLocalAddress() && adm.hasIPV4Potential())
+						altAddress = adm.getSingleHomedServiceBindAddress(NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V4);
+					else if (explicit_bind_ip instanceof Inet4Address && adm.hasIPV6Potential())
+						altAddress = adm.getSingleHomedServiceBindAddress(NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V6);
+				}catch (UnsupportedAddressTypeException e){
+				}
+
+				if(altProtocolDelegate != null && !altProtocolDelegate.explicit_bind_ip.equals(altAddress)){
+					altProtocolDelegate.destroy();
+					altProtocolDelegate = null;
+				}
+
+				if ( altAddress != null ){
+					// issue here is that we can't bind a explicit IPv6 and an 'any' IPv4 (or vice-versa) on a dual-stack impl
+					
+					if ( altAddress.isAnyLocalAddress()){
+						
+						InetAddress alt = adm.getAlternativeProtocolBindAddress( explicit_bind_ip );
+						
+						if ( alt != null ){
+							
+							altAddress = alt;
+						}
+					}
+				}
+				target_bind_ip = explicit_bind_ip;				
+
+				if(altAddress != null && altProtocolDelegate == null){
+					altProtocolDelegate = new PRUDPPacketHandlerImpl(port,altAddress,packet_transformer);
+					altProtocolDelegate.stats = stats;
+					altProtocolDelegate.primordial_handlers = primordial_handlers;
+					altProtocolDelegate.request_handler = request_handler;
+				}
+				
+			}else{
+				
+				if(altProtocolDelegate != null){
+					altProtocolDelegate.destroy();
+					altProtocolDelegate = null;
+				}
+	
+				target_bind_ip = explicit_bind_ip;
 			}
-
-			target_bind_ip = explicit_bind_ip;
-
 		}else{
 
 			InetAddress altAddress = null;
 			NetworkAdmin adm = NetworkAdmin.getSingleton();
-			try
-			{
+			try{
 				if (default_bind_ip instanceof Inet6Address && !default_bind_ip.isAnyLocalAddress() && adm.hasIPV4Potential())
 					altAddress = adm.getSingleHomedServiceBindAddress(NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V4);
 				else if (default_bind_ip instanceof Inet4Address && adm.hasIPV6Potential())
 					altAddress = adm.getSingleHomedServiceBindAddress(NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V6);
-			} catch (UnsupportedAddressTypeException e)
-			{
+			} catch (UnsupportedAddressTypeException e){
 			}
 
-			if(altProtocolDelegate != null && !altProtocolDelegate.explicit_bind_ip.equals(altAddress))
-			{
+			if(altProtocolDelegate != null && !altProtocolDelegate.explicit_bind_ip.equals(altAddress)){
 				altProtocolDelegate.destroy();
 				altProtocolDelegate = null;
 			}
 
-			if(altAddress != null && altProtocolDelegate == null)
-			{
+			if(altAddress != null && altProtocolDelegate == null){
 				altProtocolDelegate = new PRUDPPacketHandlerImpl(port,altAddress,packet_transformer);
 				altProtocolDelegate.stats = stats;
 				altProtocolDelegate.primordial_handlers = primordial_handlers;
 				altProtocolDelegate.request_handler = request_handler;
 			}
 
-
 			target_bind_ip = default_bind_ip;
 		}
 	}
@@ -568,7 +608,7 @@ PRUDPPacketHandlerImpl
 
 							// one off attempt to recover by selecting an explicit one.
 							// on  Vista (at least) we sometimes fail with wildcard but succeeed
-							// with explicit (see http://forum.vuze.com/thread.jspa?threadID=77574&tstart=0)
+							// with explicit
 
 						if ( target_bind_ip.isAnyLocalAddress()){
 
@@ -761,7 +801,7 @@ PRUDPPacketHandlerImpl
 			}
 
 			Logger.log(new LogEvent(LOGID, "PRUDPPacketReceiver: "
-					+ "DatagramSocket bind failed on port " + port, e));
+					+ "DatagramSocket bind failed on port " + port + ", bind=" + target_bind_ip, e));
 
 		}finally{
 
@@ -792,16 +832,20 @@ PRUDPPacketHandlerImpl
 		}
 	}
 
-	protected void
+	protected boolean
 	checkTimeouts()
 	{
 		long	now = SystemTime.getCurrentTime();
 
 		List	timed_out = new ArrayList();
 
+		boolean result;
+		
 		try{
 			requests_mon.enter();
 
+			result = destroyed;
+			
 			Iterator it = requests.values().iterator();
 
 			while( it.hasNext()){
@@ -810,8 +854,9 @@ PRUDPPacketHandlerImpl
 
 				long	sent_time = request.getSendTime();
 
-				if ( 	sent_time != 0 &&
-						now - sent_time >= request.getTimeout()){
+				if ( 	destroyed ||	// never going to get processed, treat as timeout
+						(	sent_time != 0 &&
+							now - sent_time >= request.getTimeout())){
 
 					it.remove();
 
@@ -844,6 +889,8 @@ PRUDPPacketHandlerImpl
 				Debug.printStackTrace(e);
 			}
 		}
+		
+		return( result );
 	}
 
 	protected void
@@ -1274,6 +1321,11 @@ PRUDPPacketHandlerImpl
 			try{
 				requests_mon.enter();
 
+				if ( destroyed ){
+					
+					throw( new PRUDPPacketHandlerException( "Handler destroyed" ));
+				}
+				
 				requests.put( new Integer( request_packet.getTransactionId()), request );
 
 			}finally{
@@ -1442,11 +1494,6 @@ PRUDPPacketHandlerImpl
 
 					request.sent();
 
-					if ( dg_packet == null ){
-
-						throw new NullPointerException("dg_packet is null");
-					}
-
 					sendToSocket( dg_packet );
 
 					// System.out.println( "sent:" + buffer.length );
