@@ -37,6 +37,7 @@ import org.eclipse.swt.widgets.*;
 import com.biglybt.core.Core;
 import com.biglybt.core.CoreFactory;
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
 import com.biglybt.core.disk.DiskManagerFileInfo;
 import com.biglybt.core.disk.DiskManagerFileInfoSet;
 import com.biglybt.core.download.DownloadManager;
@@ -61,6 +62,7 @@ import com.biglybt.ui.UIFunctionsManager;
 import com.biglybt.ui.common.table.TableCellCore;
 import com.biglybt.ui.common.table.TableColumnCore;
 import com.biglybt.ui.common.table.TableRowCore;
+import com.biglybt.ui.common.table.TableStructureEventDispatcher;
 import com.biglybt.ui.common.util.MenuItemManager;
 import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.swt.exporttorrent.wizard.ExportTorrentWizard;
@@ -69,6 +71,7 @@ import com.biglybt.ui.swt.minibar.DownloadBar;
 import com.biglybt.ui.swt.pif.UISWTGraphic;
 import com.biglybt.ui.swt.sharing.ShareUtils;
 import com.biglybt.ui.swt.views.FilesViewMenuUtil;
+import com.biglybt.ui.swt.views.columnsetup.TableColumnSetupWindow;
 import com.biglybt.ui.swt.views.table.TableSelectedRowsListener;
 import com.biglybt.ui.swt.views.table.TableViewSWT;
 import com.biglybt.ui.common.table.impl.TableContextMenuManager;
@@ -687,7 +690,7 @@ public class TorrentMenuFancy
 		List<com.biglybt.pif.ui.menus.MenuItem> listPluginItems = new ArrayList<>();
 
 		com.biglybt.pif.ui.menus.MenuItem[] items = TableContextMenuManager.getInstance().getAllAsArray(
-				tableID);
+				Utils.getBaseViewID(tableID));
 		listPluginItems.addAll(Arrays.asList(items));
 		items = MenuItemManager.getInstance().getAllAsArray(
 				MenuManager.MENU_DOWNLOAD_CONTEXT);
@@ -867,7 +870,7 @@ public class TorrentMenuFancy
 		// Queue
 		createActionButton(dms, cQuickCommands, "MyTorrentsView.menu.queue",
 				"start", start,
-				(ListenerGetOffSWT) event -> TorrentUtil.queueDataSources(dms, true));
+				(ListenerGetOffSWT) event -> TorrentUtil.queueDataSources(dms, false));
 		
 		// Force Start
 		
@@ -1261,15 +1264,16 @@ public class TorrentMenuFancy
 						@Override
 						public void buildMenu(Menu menu) {
 
-							boolean allStopped = true;
-							boolean allScanSelected = true;
-							boolean allScanNotSelected = true;
-							boolean fileMove = true;
+							boolean allStopped 			= true;
+							boolean allScanSelected 	= true;
+							boolean allScanNotSelected 	= true;
+							boolean fileMove 			= true;
 							boolean allResumeIncomplete = true;
-							boolean	hasClearableLinks = false;
+							boolean	hasClearableLinks 	= false;
 							boolean hasRevertableFiles	= false;
 							boolean lrrecheck			= false;
 							boolean allAllocatable		= true;
+							boolean allMaskDC 			= true;
 							
 							for (DownloadManager dm : dms) {
 								boolean stopped = ManagerUtils.isStopped(dm);
@@ -1308,7 +1312,9 @@ public class TorrentMenuFancy
 								
 								lrrecheck = lrrecheck || ManagerUtils.canLowResourceRecheck(dm);
 																
-								allAllocatable &= stopped && !dm.isDataAlreadyAllocated() && !dm.isDownloadComplete( false );		
+								allAllocatable &= stopped && !dm.isDataAlreadyAllocated() && !dm.isDownloadComplete( false );	
+								
+								allMaskDC = allMaskDC && dms.getBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP );
 							}
 
 							boolean fileRescan = allScanSelected || allScanNotSelected;
@@ -1453,7 +1459,25 @@ public class TorrentMenuFancy
 							});
 							itemFileSetResumeComplete.setEnabled(allStopped&&allResumeIncomplete);
 
-
+								// mask dl comp
+							
+							boolean globalMask = COConfigurationManager.getBooleanParameter( ConfigKeys.Transfer.BCFG_PEERCONTROL_HIDE_PIECE );
+							
+							MenuItem itemMaskDLComp = new MenuItem(menu, SWT.CHECK);
+							
+							if ( dms.length > 0 ){
+								itemMaskDLComp.setSelection( globalMask || allMaskDC );
+							}
+							
+							Messages.setLanguageText(itemMaskDLComp,"ConfigView.label.hap");
+							itemMaskDLComp.addListener(SWT.Selection, new ListenerDMTask(dms) {
+								@Override
+								public void run(DownloadManager dm) {
+									dm.getDownloadState().setBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP, itemMaskDLComp.getSelection());
+								}
+							});
+							
+							itemMaskDLComp.setEnabled( dms.length > 0 && !globalMask );
 
 							if (userMode > 1 && isSeedingView) {
 
@@ -1949,8 +1973,15 @@ public class TorrentMenuFancy
 					}
 				});
 
+		createRow(detailArea, "Button.selectAll", null, new Listener() {
+			@Override
+			public void handleEvent(Event event) {
+				tv.selectAll();
+			}
+		});
+		
 			// Filter
-
+		
 		if (tv.getSWTFilter() != null) {
 			createRow(detailArea, "MyTorrentsView.menu.filter", null, new Listener() {
 				@Override
@@ -1960,6 +1991,18 @@ public class TorrentMenuFancy
 			});
 		}
 
+		createRow(detailArea, "MyTorrentsView.menu.editTableColumns", "columns", new Listener() {
+			@Override
+			public void handleEvent(Event event) {
+				TableRowCore focusedRow = tv.getFocusedRow();
+				if (focusedRow == null || focusedRow.isRowDisposed()) {
+					focusedRow = tv.getRow(0);
+				}
+				String tableID = tv.getTableID();
+				new TableColumnSetupWindow(tv.getDataSourceType(), tableID, column, focusedRow,
+						TableStructureEventDispatcher.getInstance(tableID)).open();
+			}
+		});
 	}
 
 	public void buildTorrentCustomMenu_Social(Composite detailArea) {
