@@ -1123,7 +1123,7 @@ public class ImageLoader
 		return noImage;
 	}
 	
-	private static Image getNullImage() {
+	private Image getNullImage() {
 
 		if (nullImage == null) {
 			Display display = Display.getDefault();
@@ -1551,7 +1551,7 @@ public class ImageLoader
 						if ( images != null ){
 							for (int j = 0; j < images.length; j++) {
 								Image image = images[j];
-								if (isRealImage(image)) {
+								if (isRealImage(image) && image != nullImage){
 									image.dispose();
 								}
 							}
