@@ -62,6 +62,7 @@ public class Colors implements ParameterListener {
   public static Color colorShiftRight;
   public static Color colorError;
   public static Color colorErrorBG;
+  public static Color colorAltRowDefault;	// Hack for non-dark tables when "dark tables" enabled
   public static Color colorAltRow;
   public static Color colorWarning;
   public static Color black;
@@ -381,6 +382,7 @@ public class Colors implements ParameterListener {
 		background = ColorCache.getColor(display, 248, 248, 248);
 		red_ConsoleView = ColorCache.getColor(display, 255, 192, 192);
 		cyan = ColorCache.getColor(display, 0, 255, 255);
+		colorAltRowDefault = ColorCache.getColor( display, 240,244,250);
 		
 		allocateColorWarning();
 		allocateColorError();
@@ -533,52 +535,32 @@ public class Colors implements ParameterListener {
   }
 
 	public static Color getSystemColor (Device d, int id) {
-		if (Utils.isGTK3) {
-			if (id == SWT.COLOR_INFO_BACKGROUND) {
-				return ColorCache.getColor(d, 0, 0,0 );
-			}else  if (id == SWT.COLOR_INFO_FOREGROUND) {
-				return ColorCache.getColor(d, 255, 255,255 );
-			}else {
-				if ( Utils.isDarkAppearancePartial()) {
-					if ( id == SWT.COLOR_BLACK ) {
-						return( white );
-					}else if ( id == SWT.COLOR_WHITE ) {
-						return( black );
+		if ( !Utils.isDarkAppearanceNative()){
+			if (Utils.isGTK3) {
+				if (id == SWT.COLOR_INFO_BACKGROUND) {
+					return ColorCache.getColor(d, 0, 0,0 );
+				}else  if (id == SWT.COLOR_INFO_FOREGROUND) {
+					return ColorCache.getColor(d, 255, 255,255 );
+				}else {
+					if ( Utils.isDarkAppearancePartial()) {
+						if ( id == SWT.COLOR_BLACK ) {
+							return( white );
+						}else if ( id == SWT.COLOR_WHITE ) {
+							return( black );
+						}
 					}
 				}
 			}
 		}
-		return d.getSystemColor(id);
-	}
-	
-	public Color
-	getFadedColor(
-		Color	c )
-	{
-		HSLColor hslColor = new HSLColor();
-		hslColor.initHSLbyRGB(c.getRed(), c.getGreen(), c.getBlue());
 		
-		int iSat = hslColor.getSaturation();
-		int luminence = hslColor.getLuminence();
-		if (luminence < 20) {
-			if (iSat > 10) {
-				hslColor.setSaturation(iSat / 2);
-				hslColor.brighten(1.25f);
-			}
-		} else {
-			if (iSat > 10) {
-				hslColor.setSaturation(iSat / 2);
-				hslColor.brighten(0.75f);
-			} 
-		}
-
-		return( ColorCache.getColor(display, hslColor.getRed(),	hslColor.getGreen(), hslColor.getBlue()));
+		return d.getSystemColor(id);
 	}
 	
 	public Color
 	getSlightlyFadedColor(
 		Color	c )
 	{
+		boolean darkMode = Utils.isDarkAppearanceNative();
 		HSLColor hslColor = new HSLColor();
 		hslColor.initHSLbyRGB(c.getRed(), c.getGreen(), c.getBlue());
 		
@@ -586,13 +568,13 @@ public class Colors implements ParameterListener {
 		int luminence = hslColor.getLuminence();
 		if (luminence < 20) {
 			if (iSat > 10) {
-				hslColor.setSaturation((int)(iSat / 1.25));
-				hslColor.brighten(1.12f);
+				hslColor.setSaturation((int)(iSat / (darkMode?1.12:1.25)));
+				hslColor.brighten((darkMode?1.06f:1.12f));
 			}
 		} else {
 			if (iSat > 10) {
-				hslColor.setSaturation((int)(iSat / 1.25));
-				hslColor.brighten(0.63f);
+				hslColor.setSaturation((int)(iSat / (darkMode?1.12:1.25)));
+				hslColor.brighten(darkMode?0.80f:0.63f);
 			} 
 		}
 
