@@ -61,7 +61,7 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
 
 
   Display display;
-  private boolean sleak;
+  private boolean sleak = false;
   private boolean terminated;
   private Thread runner;
   private final IUIIntializer initializer;
@@ -79,322 +79,321 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
 	instance = this;
 	
     Display.setAppName(Constants.APP_NAME);
+ 
+    try {
+    	display = Display.getCurrent();
+    	
+    	if ( display == null ){
+    		
+    		if (System.getProperty("SWT.Device.DEBUG", "0").equals("1")) {
+    			Device.DEBUG = true;
+    		}
+    		
+    		if ( System.getProperty( "biglybt.sleak.active", "0" ).equals( "1" )){
+    			
+    			display = Display.getDefault();
+    			
+    			if ( display != null ){
+    				
+    				sleak = true;
+    			}
+    		}
+    		
+    		if ( display == null ){
+    		
+    			display = new Display();
+    		}
+    	}
+    } catch(Exception e) {
+    	display = new Display();
+    	
+    } catch (UnsatisfiedLinkError ue) {
+    	String sMin = "3.4";
+    	try {
+    		sMin = "" +  (((int)(SWT.getVersion() / 100)) / 10.0);
+    	} catch (Throwable t) {
+    	}
+    	try{
+    		String tempDir = System.getProperty ("swt.library.path");
+    		if (tempDir == null) {
+    			tempDir = System.getProperty ("java.io.tmpdir");
+    		}
+    		Debug.out("Loading SWT Libraries failed. "
+    				+ "Typical causes:\n\n"
+    				+ "(1) swt.jar is not for your os architecture ("
+    				+ System.getProperty("os.arch") + ").  "
+    				+ "You can get a new swt.jar (Min Version: " + sMin + ") "
+    				+ "from http://eclipse.org/swt"
+    				+ "\n\n"
+    				+ "(2) No write access to '" + tempDir
+    				+ "'. SWT will extract libraries contained in the swt.jar to this dir.\n", ue);
 
-	if ( false ){
-		/* Hack to run Sleak - drop Sleak.java into this package
-	    DeviceData data = new DeviceData();
-	
-	    data.tracking = true;
-	
-	    display = new Display(data);
-	
-	    Sleak sleakView = new Sleak();
-	
-	    sleakView.open();
-	    */
-	}else{
-    
-		try {
-			display = Display.getCurrent();
-			if ( display == null ){
-				if (System.getProperty("SWT.Device.DEBUG", "0").equals("1")) {
-					Device.DEBUG = true;
-				}
-				display = new Display();
-				sleak = false;
-			}else{
-				sleak = false;
-			}
-		} catch(Exception e) {
-			display = new Display();
-			sleak = false;
-		} catch (UnsatisfiedLinkError ue) {
-			String sMin = "3.4";
-			try {
-				sMin = "" +  (((int)(SWT.getVersion() / 100)) / 10.0);
-			} catch (Throwable t) {
-			}
-			try{
-				String tempDir = System.getProperty ("swt.library.path");
-				if (tempDir == null) {
-					tempDir = System.getProperty ("java.io.tmpdir");
-				}
-				Debug.out("Loading SWT Libraries failed. "
-						+ "Typical causes:\n\n"
-						+ "(1) swt.jar is not for your os architecture ("
-						+ System.getProperty("os.arch") + ").  "
-						+ "You can get a new swt.jar (Min Version: " + sMin + ") "
-						+ "from http://eclipse.org/swt"
-						+ "\n\n"
-						+ "(2) No write access to '" + tempDir
-						+ "'. SWT will extract libraries contained in the swt.jar to this dir.\n", ue);
+    		app.stopIt(false);
+    		terminated = true;
 
-				app.stopIt(false);
-				terminated = true;
-
-				PlatformManagerFactory.getPlatformManager().dispose();
-			} catch (Throwable t) {
-			}
-			return;
-		}
-	}
+    		PlatformManagerFactory.getPlatformManager().dispose();
+    	} catch (Throwable t) {
+    	}
+    	return;
+    }
     
     Thread.currentThread().setName("SWT Thread");
 
 	Utils.initialize( display );
 
-    primaryMonitor = display.getPrimaryMonitor();
-    AEDiagnostics.addEvidenceGenerator(this);
-
-    UISwitcherUtil.addListener(new UISwitcherListener() {
-			@Override
-			public void uiSwitched(String ui) {
-				MessageBoxShell mb = new MessageBoxShell(
-						MessageText.getString("dialog.uiswitcher.restart.title"),
-						MessageText.getString("dialog.uiswitcher.restart.text"),
-						new String[] {
-							MessageText.getString("UpdateWindow.restart"),
-							MessageText.getString("UpdateWindow.restartLater"),
-						}, 0);
-				mb.open(new UserPrompterResultListener() {
-					@Override
-					public void prompterClosed(int result) {
-						if (result != 0) {
-							return;
-						}
-						UIFunctions uif = UIFunctionsManager.getUIFunctions();
-						if (uif != null) {
-							uif.dispose(true);
-						}
-					}
-				});
-			}
-		});
-
-    // SWT.OpenDocument is only available on 3637
-		try {
-			Field fldOpenDoc = SWT.class.getDeclaredField("OpenDocument");
-			int SWT_OpenDocument = fldOpenDoc.getInt(null);
-
-			display.addListener(SWT_OpenDocument, new Listener() {
+	Utils.execSWTThread(()->{
+	    primaryMonitor = display.getPrimaryMonitor();
+	    AEDiagnostics.addEvidenceGenerator(this);
+	
+	    UISwitcherUtil.addListener(new UISwitcherListener() {
 				@Override
-				public void handleEvent(final Event event) {
-					CoreFactory.addCoreRunningListener(new CoreRunningListener() {
+				public void uiSwitched(String ui) {
+					MessageBoxShell mb = new MessageBoxShell(
+							MessageText.getString("dialog.uiswitcher.restart.title"),
+							MessageText.getString("dialog.uiswitcher.restart.text"),
+							new String[] {
+								MessageText.getString("UpdateWindow.restart"),
+								MessageText.getString("UpdateWindow.restartLater"),
+							}, 0);
+					mb.open(new UserPrompterResultListener() {
 						@Override
-						public void coreRunning(Core core) {
-							UIFunctionsManagerSWT.getUIFunctionsSWT().openTorrentOpenOptions(
-									Utils.findAnyShell(), null, new String[] {
-										event.text
-									}, false, false);
+						public void prompterClosed(int result) {
+							if (result != 0) {
+								return;
+							}
+							UIFunctions uif = UIFunctionsManager.getUIFunctions();
+							if (uif != null) {
+								uif.dispose(true);
+							}
 						}
 					});
 				}
 			});
-		} catch (Throwable t) {
-		}
-
-
-		Listener lShowMainWindow = new Listener() {
-			@Override
-			public void handleEvent(Event event) {
-				if ( event.type == SWT.Activate ){
-
-					if ( AERunStateHandler.isDelayedUI()){
-
-						Debug.out( "Ignoring activate event as delay start" );
-
-						return;
-					}
-				}
-				Shell as = Display.getDefault().getActiveShell();
-				if (as != null) {
-					as.setVisible(true);
-					as.forceActive();
-					return;
-				}
-				UIFunctionsSWT uif = UIFunctionsManagerSWT.getUIFunctionsSWT();
-				if (uif != null) {
-					Shell mainShell = uif.getMainShell();
-					if (	mainShell == null || 
-							mainShell.isDisposed() ||  
-							!mainShell.isVisible() || 
-							mainShell.getMinimized()) {
-						
-						if ( !COConfigurationManager.getBooleanParameter( "Reduce Auto Activate Window" )){
-
-							uif.bringToFront(false);
-						}
-					}
-				}
-			}
-		};
-		display.addListener(SWT.Activate, lShowMainWindow);
-		display.addListener(SWT.Selection, lShowMainWindow);
-
-		display.addListener(SWT.Dispose, new Listener() {
-			@Override
-			public void handleEvent(Event event) {
-				displayDisposed = true;
-			}
-		});
-
-		if (Constants.isOSX) {
-
-			// On Cocoa, we get a Close trigger on display.  Need to check if all
-			// platforms send this.
-			display.addListener(SWT.Close, new Listener() {
-				@Override
-				public void handleEvent(Event event) {
-					UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
-					if (uiFunctions != null) {
-						uiFunctions.dispose(false);
-					}
-					
-						// we want normal closedown to proceed, not OSX to dispose of things abruptly
-					
-					event.doit = false;
-				}
-			});
-
-			MenuFactory.initSystemMenu();
-		}
-		
-		if (Constants.isWindows) {
-			/* Windows Bug: Button in a Composite with a background color set, will
-			 * result in a thin white border around button.
-			 * Marked as WONTFIX by eclipse:
-			 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=515175
-			 *
-			 * Our hack is to set the Button's "state"'s PARENT_BACKGROUND (1<<10) bit.
-			 */
+	
+	    // SWT.OpenDocument is only available on 3637
 			try {
-				Field fieldState = Widget.class.getDeclaredField("state");
-				fieldState.setAccessible(true);
-				display.addListener(SWT.Skin, event -> {
-					if (event.widget == null || event.widget.isDisposed()) {
-						return;
-					}
-					if (event.widget instanceof Shell) {
-						// Lazy way to ensure all children inherit background color
-						((Shell) event.widget).setBackgroundMode(SWT.INHERIT_DEFAULT);
-					} else if (event.widget instanceof Button
-							&& (event.widget.getStyle() & SWT.PUSH) != 0) {
-						try {
-							int stateVal = (int) fieldState.get(event.widget);
-							stateVal |= 1 << 10;
-							fieldState.set(event.widget, stateVal);
-						} catch (Throwable e) {
-							e.printStackTrace();
-						}
+				Field fldOpenDoc = SWT.class.getDeclaredField("OpenDocument");
+				int SWT_OpenDocument = fldOpenDoc.getInt(null);
+	
+				display.addListener(SWT_OpenDocument, new Listener() {
+					@Override
+					public void handleEvent(final Event event) {
+						CoreFactory.addCoreRunningListener(new CoreRunningListener() {
+							@Override
+							public void coreRunning(Core core) {
+								UIFunctionsManagerSWT.getUIFunctionsSWT().openTorrentOpenOptions(
+										Utils.findAnyShell(), null, new String[] {
+											event.text
+										}, false, false);
+							}
+						});
 					}
 				});
-			} catch (Throwable e) {
+			} catch (Throwable t) {
 			}
-		}
-		
-		if (Constants.isWindows) {
-		
-			/* Windows "Bug" that Eclipse devs will never fix:
-			 * Bug 75766 - Allow mouse wheel to scroll without focus
-			 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=75766
-			 */
-			display.addFilter(SWT.MouseWheel, e -> {
-				Widget focusControl = e.widget;
-				Control cursorControl = display.getCursorControl();
-				if (focusControl == cursorControl) {
-					return;
-				}
-				while (cursorControl != null) {
-					if (cursorControl instanceof ScrolledComposite) {
-						ScrollBar verticalBar = ((Scrollable) cursorControl).getVerticalBar();
-						if (verticalBar != null) {
-							ScrolledComposite sc = (ScrolledComposite) cursorControl;
-							Point origin = sc.getOrigin();
-							sc.setOrigin(origin.x, origin.y - verticalBar.getIncrement() * e.count);
-							e.doit = false;
-							break;
-						}
-					}
-					// Can't find a good way to Scroll a Scrollable, so we have a custom
-					// hack.  If the Vertical Bar has a getData("ScrollOnMouseOver") set
-					// to non-null, we call setSelection on the bar.  If the getData is
-					// a Runnable, we run it afterwards.  This allows the widget to
-					// handle any scrolling or refreshing itself.
-					if (cursorControl instanceof Scrollable) {
-						ScrollBar verticalBar = ((Scrollable) cursorControl).getVerticalBar();
-						if (verticalBar != null && verticalBar.isEnabled()
-								&& verticalBar.getData("ScrollOnMouseOver") != null) {
-							int oldPos = verticalBar.getSelection();
-							int newPos = oldPos - (verticalBar.getIncrement() * e.count);
-							// This will set vertical bar position, but not update control
-							verticalBar.setSelection(newPos);
-
-							Object o = verticalBar.getData("ScrollOnMouseOver");
-							if (o instanceof Runnable) {
-								try {
-									((Runnable) o).run();
-								} catch (Throwable ignore) {
-								}
-							}
-
-							// This just doesn't work on anything.  It scrolls the control along with the scrollbar
-							//Point location = cursorControl.getLocation();
-							//location.y -= verticalBar.getIncrement() * e.count;
-							//cursorControl.setLocation(location);
-							e.doit = false;
-							break;
-						}
-					}
-
-					cursorControl = cursorControl.getParent();
-				}
-			});
-
-		}
-		
-		if (Constants.isOSX ) {
-			// sidebar not redrawing on mouse-wheel scroll
-			display.addFilter(SWT.MouseWheel, e -> {
-				Widget focusControl = e.widget;
-				Control control = focusControl instanceof Control?(Control)focusControl:null;
-				while (control != null) {
-					
-					if (control instanceof Scrollable) {
-						ScrollBar verticalBar = ((Scrollable) control).getVerticalBar();
-						if (verticalBar != null && verticalBar.isEnabled()
-								&& verticalBar.getData("ScrollOnMouseOver2") != null) {
-							
-							Object o = verticalBar.getData("ScrollOnMouseOver2");
-							if (o instanceof Runnable) {
-								try {
-									((Runnable) o).run();
-								} catch (Throwable ignore) {
-								}
-							}
-
-							break;
-						}
-					}
-
-					control = control.getParent();
-				}
-			});
-
-		}
-
-		if (app != null) {
-			app.runInSWTThread();
-			runner = new Thread(new AERunnable() {
+	
+	
+			Listener lShowMainWindow = new Listener() {
 				@Override
-				public void runSupport() {
-					app.run();
+				public void handleEvent(Event event) {
+					if ( event.type == SWT.Activate ){
+	
+						if ( AERunStateHandler.isDelayedUI()){
+	
+							Debug.out( "Ignoring activate event as delay start" );
+	
+							return;
+						}
+					}
+					Shell as = Display.getDefault().getActiveShell();
+					if (as != null) {
+						as.setVisible(true);
+						as.forceActive();
+						return;
+					}
+					UIFunctionsSWT uif = UIFunctionsManagerSWT.getUIFunctionsSWT();
+					if (uif != null) {
+						Shell mainShell = uif.getMainShell();
+						if (	mainShell == null || 
+								mainShell.isDisposed() ||  
+								!mainShell.isVisible() || 
+								mainShell.getMinimized()) {
+							
+							if ( !COConfigurationManager.getBooleanParameter( "Reduce Auto Activate Window" )){
+	
+								uif.bringToFront(false);
+							}
+						}
+					}
 				}
-			}, "Main Thread");
-			runner.start();
-		}
+			};
+			display.addListener(SWT.Activate, lShowMainWindow);
+			display.addListener(SWT.Selection, lShowMainWindow);
+	
+			display.addListener(SWT.Dispose, new Listener() {
+				@Override
+				public void handleEvent(Event event) {
+					displayDisposed = true;
+				}
+			});
+	
+			if (Constants.isOSX) {
+	
+				// On Cocoa, we get a Close trigger on display.  Need to check if all
+				// platforms send this.
+				display.addListener(SWT.Close, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+						if (uiFunctions != null) {
+							uiFunctions.dispose(false);
+						}
+						
+							// we want normal closedown to proceed, not OSX to dispose of things abruptly
+						
+						event.doit = false;
+					}
+				});
+	
+				MenuFactory.initSystemMenu();
+			}
+			
+			if (Constants.isWindows) {
+				/* Windows Bug: Button in a Composite with a background color set, will
+				 * result in a thin white border around button.
+				 * Marked as WONTFIX by eclipse:
+				 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=515175
+				 *
+				 * Our hack is to set the Button's "state"'s PARENT_BACKGROUND (1<<10) bit.
+				 */
+				try {
+					Field fieldState = Widget.class.getDeclaredField("state");
+					fieldState.setAccessible(true);
+					display.addListener(SWT.Skin, event -> {
+						if (event.widget == null || event.widget.isDisposed()) {
+							return;
+						}
+						if (event.widget instanceof Shell) {
+							// Lazy way to ensure all children inherit background color
+							((Shell) event.widget).setBackgroundMode(SWT.INHERIT_DEFAULT);
+						} else if (event.widget instanceof Button
+								&& (event.widget.getStyle() & SWT.PUSH) != 0) {
+							try {
+								int stateVal = (int) fieldState.get(event.widget);
+								stateVal |= 1 << 10;
+								fieldState.set(event.widget, stateVal);
+							} catch (Throwable e) {
+								e.printStackTrace();
+							}
+						}
+					});
+				} catch (Throwable e) {
+				}
+			}
+			
+			if (Constants.isWindows) {
+			
+				/* Windows "Bug" that Eclipse devs will never fix:
+				 * Bug 75766 - Allow mouse wheel to scroll without focus
+				 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=75766
+				 */
+				display.addFilter(SWT.MouseWheel, e -> {
+					Widget focusControl = e.widget;
+					Control cursorControl = display.getCursorControl();
+					if (focusControl == cursorControl) {
+						return;
+					}
+					while (cursorControl != null) {
+						if (cursorControl instanceof ScrolledComposite) {
+							ScrollBar verticalBar = ((Scrollable) cursorControl).getVerticalBar();
+							if (verticalBar != null) {
+								ScrolledComposite sc = (ScrolledComposite) cursorControl;
+								Point origin = sc.getOrigin();
+								sc.setOrigin(origin.x, origin.y - verticalBar.getIncrement() * e.count);
+								e.doit = false;
+								break;
+							}
+						}
+						// Can't find a good way to Scroll a Scrollable, so we have a custom
+						// hack.  If the Vertical Bar has a getData("ScrollOnMouseOver") set
+						// to non-null, we call setSelection on the bar.  If the getData is
+						// a Runnable, we run it afterwards.  This allows the widget to
+						// handle any scrolling or refreshing itself.
+						if (cursorControl instanceof Scrollable) {
+							ScrollBar verticalBar = ((Scrollable) cursorControl).getVerticalBar();
+							if (verticalBar != null && verticalBar.isEnabled()
+									&& verticalBar.getData("ScrollOnMouseOver") != null) {
+								int oldPos = verticalBar.getSelection();
+								int newPos = oldPos - (verticalBar.getIncrement() * e.count);
+								// This will set vertical bar position, but not update control
+								verticalBar.setSelection(newPos);
+	
+								Object o = verticalBar.getData("ScrollOnMouseOver");
+								if (o instanceof Runnable) {
+									try {
+										((Runnable) o).run();
+									} catch (Throwable ignore) {
+									}
+								}
+	
+								// This just doesn't work on anything.  It scrolls the control along with the scrollbar
+								//Point location = cursorControl.getLocation();
+								//location.y -= verticalBar.getIncrement() * e.count;
+								//cursorControl.setLocation(location);
+								e.doit = false;
+								break;
+							}
+						}
+	
+						cursorControl = cursorControl.getParent();
+					}
+				});
+	
+			}
+			
+			if (Constants.isOSX ) {
+				// sidebar not redrawing on mouse-wheel scroll
+				display.addFilter(SWT.MouseWheel, e -> {
+					Widget focusControl = e.widget;
+					Control control = focusControl instanceof Control?(Control)focusControl:null;
+					while (control != null) {
+						
+						if (control instanceof Scrollable) {
+							ScrollBar verticalBar = ((Scrollable) control).getVerticalBar();
+							if (verticalBar != null && verticalBar.isEnabled()
+									&& verticalBar.getData("ScrollOnMouseOver2") != null) {
+								
+								Object o = verticalBar.getData("ScrollOnMouseOver2");
+								if (o instanceof Runnable) {
+									try {
+										((Runnable) o).run();
+									} catch (Throwable ignore) {
+									}
+								}
+	
+								break;
+							}
+						}
+	
+						control = control.getParent();
+					}
+				});
+	
+			}
+	
+			if (app != null) {
+				app.runInSWTThread();
+				runner = new Thread(new AERunnable() {
+					@Override
+					public void runSupport() {
+						app.run();
+					}
+				}, "Main Thread");
+				runner.start();
+			}
+	});
 
-
-    if(!sleak) {
+    if ( !sleak ){
       while(display != null && !display.isDisposed() && !terminated) {
         try {
             if (display != null && !display.readAndDispatch())
