@@ -245,6 +245,13 @@ SBC_SearchResult
 		return( result.getCategory() );
 	}
 
+	@Override
+	public String[] 
+	getTags()
+	{
+		return( result.getTags());
+	}
+	
 	@Override
 	public long
 	getTime()
