@@ -66,7 +66,6 @@ import com.biglybt.ui.swt.components.BufferedLabel;
 import com.biglybt.ui.swt.pif.UISWTViewEvent;
 import com.biglybt.ui.swt.pifimpl.UISWTViewCoreEventListener;
 import com.biglybt.ui.swt.pifimpl.UISWTViewBuilderCore;
-import com.biglybt.ui.swt.utils.FontUtils;
 import com.biglybt.ui.swt.views.file.FileInfoView;
 import com.biglybt.ui.swt.views.table.*;
 import com.biglybt.ui.swt.views.table.impl.TableViewFactory;
@@ -92,11 +91,17 @@ import com.biglybt.pif.ui.tables.TableRowRefreshListener;
 public class FilesView
 	extends TableViewTab<DiskManagerFileInfo>
 	implements TableDataSourceChangedListener, TableSelectionListener,
-	TableViewSWTMenuFillListener, TableRefreshListener,
+	TableViewSWTMenuFillListener, TableRefreshListener, TableExpansionChangeListener,
 	DownloadManagerStateAttributeListener, DownloadManagerListener,
 	TableLifeCycleListener, TableViewFilterCheckEx<DiskManagerFileInfo>, KeyListener, ParameterListener,
 	UISWTViewCoreEventListener, ViewTitleInfo
 {
+	private static final Object	KEY_DM_TREE_STATE 		= new Object();
+	private static final Object	KEY_DM_SELECTION_STATE	= new Object();
+	
+	private static final int	ACTION_EXPAND 	= 0;
+	private static final int	ACTION_COLLAPSE = 1;
+	
 	public static final Class<com.biglybt.pif.disk.DiskManagerFileInfo> PLUGIN_DS_TYPE = com.biglybt.pif.disk.DiskManagerFileInfo.class;
 	boolean refreshing = false;
 
@@ -189,6 +194,7 @@ public class FilesView
 		tv.addMenuFillListener(this);
 		tv.addLifeCycleListener(this);
 		tv.addKeyListener(this);
+		tv.addExpansionChangeListener(this);
 
 		tv.addRefreshListener( 
 			new TableRowRefreshListener(){
@@ -277,10 +283,8 @@ public class FilesView
 				
 				COConfigurationManager.setParameter("FilesView.use.tree", tree_view);
 				
-					// grab before column visibility as this resets the selection :(
+				prepareSelectionState();
 				
-				selection_outstanding	= tv.getSelectedDataSources();
-
 				if ( tree_view ){
 					
 					TableColumnSWTUtils.changeColumnVisiblity( tv, tv.getTableColumn( "name" ), true );
@@ -306,13 +310,12 @@ public class FilesView
 
 		BubbleTextBox bubbleTextBox = new BubbleTextBox(cTop, SWT.BORDER | SWT.SEARCH | SWT.ICON_SEARCH | SWT.ICON_CANCEL | SWT.SINGLE);
 		Composite mainBubbleWidget = bubbleTextBox.getMainWidget();
-		bubbleTextBox.setMessage(MessageText.getString("TorrentDetailsView.filter"));
 
 		FormData fd = new FormData();
 		fd.right = new FormAttachment(100, 0);
-		fd.height = (int) (FontUtils.getFontHeightInPX(mainBubbleWidget.getFont()) * 1.4);
 		fd.width = 140;
-		mainBubbleWidget.setLayoutData(fd);
+		
+		bubbleTextBox.setMessageAndLayout(MessageText.getString("TorrentDetailsView.filter") , fd);
 
 		fd = new FormData();
 		fd.top = new FormAttachment(mainBubbleWidget, 10, SWT.CENTER);
@@ -445,6 +448,8 @@ public class FilesView
 			return;
 		}
 
+		prepareSelectionState();
+		
 		addManagerListeners( managers );
 
 		if (!tv.isDisposed()) {
@@ -465,23 +470,113 @@ public class FilesView
 		}
 	}
 
-	// @see TableSelectionListener#deselected(TableRowCore[])
 	@Override
 	public void deselected(TableRowCore[] rows) {
-		updateSelectedContent();
+		
 	}
 
-	// @see TableSelectionListener#focusChanged(TableRowCore)
 	@Override
 	public void focusChanged(TableRowCore focus) {
 	}
 
-	// @see TableSelectionListener#selected(TableRowCore[])
 	@Override
 	public void selected(TableRowCore[] rows) {
-		updateSelectedContent();
 	}
 
+	private void
+	prepareSelectionState()
+	{
+		if ( managers == null ){
+			return;
+		}
+		
+		Map<DownloadManager,Set<Integer>> pending = null;
+		
+		synchronized( KEY_DM_SELECTION_STATE ){
+			
+			for ( DownloadManager dm: managers ){
+	
+				Set<Integer> sel = (Set<Integer>)dm.getUserData( KEY_DM_SELECTION_STATE );
+				
+				if ( sel != null ){
+					
+					if ( pending == null ){
+						
+						pending = new IdentityHashMap<>();
+					}
+					
+					pending.put( dm, sel );
+				}
+			}
+		}
+		
+		selection_outstanding = pending;
+	}
+	
+	@Override
+	public void
+	selectionChanged(
+		TableRowCore[] 		selected_rows,
+		TableRowCore[] 		deselected_rows )
+	{	
+		Map<DownloadManager,Set<Integer>>	sel_map = new HashMap<>();
+		
+		IdentityHashSet<DownloadManager>	unselected_dms = new IdentityHashSet<>();
+		
+		if ( managers != null ){
+			
+			unselected_dms.addAll( Arrays.asList( managers ));
+		}
+		
+		List<Object> selected_objects = tv.getSelectedDataSources();
+		
+		for ( Object selected: selected_objects ){
+			
+			DiskManagerFileInfo file = (DiskManagerFileInfo)selected;
+			
+			DownloadManager dm = file.getDownloadManager();
+						
+			Set<Integer> sel = sel_map.get( dm );
+			
+			if ( sel == null ){
+				
+				sel = new HashSet<>();
+				
+				sel_map.put( dm, sel );
+			}
+			
+			if ( file instanceof FilesViewNodeInner ){
+				
+				int	uid = ((FilesViewNodeInner)file).getUID();
+				
+				sel.add( uid + 1000000000 );
+				
+			}else{
+				
+				sel.add( file.getIndex());
+			}
+		}
+		
+		synchronized( KEY_DM_SELECTION_STATE ){
+			
+			for ( Map.Entry<DownloadManager,Set<Integer>> entry: sel_map.entrySet()){
+			
+				DownloadManager dm = entry.getKey();
+				
+				dm.setUserData( KEY_DM_SELECTION_STATE, entry.getValue());
+				
+				unselected_dms.remove( dm );
+			}
+		
+			for ( DownloadManager dm: unselected_dms ){
+								
+				dm.setUserData( KEY_DM_SELECTION_STATE, null );
+			}
+		}
+		
+		updateSelectedContent();
+	}
+	
 	@Override
 	public void
 	stateChanged(
@@ -754,11 +849,11 @@ public class FilesView
 				
 				if ( node.isExpanded()){
 									
-					doTreeAction(nodes, 1, false );
+					doTreeAction(nodes, ACTION_COLLAPSE, false );
 					
 				}else{
 										
-					doTreeAction(nodes, 0, false );
+					doTreeAction(nodes, ACTION_EXPAND, false );
 				}
 			}finally{
 				
@@ -906,11 +1001,9 @@ public class FilesView
 		boolean									recursive,
 		boolean									test_only )
 	{
-		TableRowCore row = node_to_row_map.get( node );
-		
 		if ( !node.isExpanded()){
 			
-			if ( action == 0 ){
+			if ( action == ACTION_EXPAND ){
 								
 				if ( test_only ){
 				
@@ -918,7 +1011,12 @@ public class FilesView
 					
 				}else{
 					
-					row.setExpanded( true );
+					TableRowCore row = node_to_row_map.get( node );
+					
+					if ( row != null ){
+					
+						row.setExpanded( true );
+					}
 				}
 			}
 		}
@@ -946,7 +1044,7 @@ public class FilesView
 		
 		if ( node.isExpanded()){
 			
-			if ( action == 1 ){
+			if ( action == ACTION_COLLAPSE ){
 								
 				if ( test_only ){
 				
@@ -979,7 +1077,12 @@ public class FilesView
 						}
 					}
 					
-					row.setExpanded( false );
+					TableRowCore row = node_to_row_map.get( node );
+					
+					if ( row != null ){
+					
+						row.setExpanded( false );
+					}
 				}
 			}
 		}
@@ -1003,17 +1106,31 @@ public class FilesView
 			
 			List<DiskManagerFileInfo> inner_files = new ArrayList<>();
 			
+			Map<DiskManagerFileInfo,String>	structure_map = new HashMap<>();
+			
 			for ( int i=0;i<data_sources.length;i++ ){
+				
 				DiskManagerFileInfo file = (DiskManagerFileInfo)data_sources[i];
 				
 				if ( file instanceof FilesView.FilesViewNodeInner ){
 
 					FilesView.FilesViewNodeInner inner = (FilesView.FilesViewNodeInner )file;
+				
+					List<DiskManagerFileInfo> temp = inner.getFiles( true );
 					
-					inner_files.addAll( inner.getFiles( true ));
+					FilesView.FilesViewNodeInner parent = inner.getParent();
+					
+					String path = parent==null?"":parent.getPath();
+					
+					for ( DiskManagerFileInfo f: temp ){
+						
+						structure_map.put( f, path );
+					}
+					
+					inner_files.addAll( temp );
 					
 					inners.add( inner );
-					
+									
 				}else{
 				
 					files.add( file );
@@ -1028,6 +1145,7 @@ public class FilesView
 					menu,
 					new DownloadManager[]{ managers[0] },
 					new DiskManagerFileInfo[][]{ files.toArray(new DiskManagerFileInfo[files.size()]) },
+					null,
 					false,
 					false );
 				
@@ -1040,10 +1158,10 @@ public class FilesView
 				mi.addListener(
 					SWT.Selection,
 					e->{
-						doTreeAction( inners, 0, false );
+						doTreeAction( inners, ACTION_EXPAND, false );
 					});
 				
-				mi.setEnabled( doTreeAction( inners, 0, true ));
+				mi.setEnabled( doTreeAction( inners, ACTION_EXPAND, true ));
 				
 				mi = new MenuItem( menu, SWT.PUSH );
 				
@@ -1052,10 +1170,10 @@ public class FilesView
 				mi.addListener(
 					SWT.Selection,
 					e->{
-						doTreeAction( inners, 1, false );
+						doTreeAction( inners, ACTION_COLLAPSE, false );
 					});
 				
-				mi.setEnabled( doTreeAction( inners, 1, true ));
+				mi.setEnabled( doTreeAction( inners, ACTION_COLLAPSE, true ));
 				
 				new MenuItem( menu, SWT.SEPARATOR );
 				
@@ -1067,6 +1185,7 @@ public class FilesView
 							menu,
 							new DownloadManager[]{ managers[0] },
 							new DiskManagerFileInfo[][]{ inner_files.toArray(new DiskManagerFileInfo[inner_files.size()]) },
+							structure_map,
 							false,
 							true );
 									
@@ -1119,15 +1238,15 @@ public class FilesView
 
 			if ( files_list.length > 0 ){
 				
-				FilesViewMenuUtil.fillMenu(tv, sColumnName, menu, manager_list, files_list, true, false );
+				FilesViewMenuUtil.fillMenu(tv, sColumnName, menu, manager_list, files_list, null, true, false );
 			}
 		}
 	}
 
 
  
-  private boolean 		force_refresh = false;
-  private List<Object> 	selection_outstanding = null;
+  private boolean 								force_refresh 			= false;
+  private Map<DownloadManager,Set<Integer>> 	selection_outstanding 	= null;
   
   @Override
   public void tableRefresh() {
@@ -1349,7 +1468,7 @@ public class FilesView
 	{
 		if ( e.keyCode == SWT.F2 && (e.stateMask & SWT.MODIFIER_MASK) == 0 ){
 			
-			FilesViewMenuUtil.rename(tv, tv.getSelectedDataSources(true), true, false,false);
+			FilesViewMenuUtil.rename(tv, tv.getSelectedDataSources(true), null, true, false,false);
 			
 			e.doit = false;
 			
@@ -1552,12 +1671,67 @@ public class FilesView
 		disableTableWhenEmpty	= b;
 	}
 	
+	public void 
+	rowExpanded(
+		TableRowCore row )
+	{
+		updateTreeExpansionState( row, true );
+	}
+
+	public void 
+	rowCollapsed(
+		TableRowCore row )
+	{
+		updateTreeExpansionState( row, false );
+	}
+	
+	private void
+	updateTreeExpansionState(
+		TableRowCore	row,
+		boolean			expanded )
+	{
+		Object ds = row.getDataSource( true );
+		
+		if ( ds instanceof FilesViewNodeInner ){
+			
+			FilesViewNodeInner node = (FilesViewNodeInner)ds;
+			
+			DownloadManager dm = node.getDownloadManager();
+			
+			if ( dm != null ){
+				
+				int uid = node.getUID();
+				
+				synchronized( KEY_DM_TREE_STATE ){
+				
+					Map<Integer,Boolean> map = (Map<Integer,Boolean>)dm.getUserData( KEY_DM_TREE_STATE );
+					
+					if ( map == null ){
+						
+						map = new HashMap<>();
+						
+						dm.setUserData( KEY_DM_TREE_STATE, map );
+					}
+					
+					if ( expanded ){
+						
+						map.remove( uid );
+						
+					}else{
+						
+						map.put( uid, Boolean.TRUE );
+					}
+				}
+			}
+		}
+	}
+	
 	private void
 	updateTable()
 	{
 		boolean	sync = false;
 		
-		List<Object>	to_select;
+		Map<DownloadManager,Set<Integer>>	to_select;
 		
 		if ( selection_outstanding != null  ){
 						
@@ -1609,50 +1783,33 @@ public class FilesView
 							List<TableRowCore>	selected_rows = new ArrayList<>();
 							
 							TableRowCore[] tv_rows = tv.getRowsAndSubRows(false);
-							
-							Map<DiskManagerFileInfo,TableRowCore>	file_to_row_map = new HashMap<>();
-							
+														
 							for ( TableRowCore tv_row: tv_rows ){
 								
 								DiskManagerFileInfo ds_file = (DiskManagerFileInfo)tv_row.getDataSource(true);
 								
-								if ( ds_file instanceof FilesViewNodeLeaf ){
+								Set<Integer> sel = to_select.get( ds_file.getDownloadManager());
+								
+								if ( sel != null ){
 									
-									DiskManagerFileInfo target = ((FilesViewNodeLeaf)ds_file).getTarget();
-									
-									file_to_row_map.put( target, tv_row );
-									
-								}else if ( ds_file instanceof FilesViewNodeInner ){
+									if ( ds_file instanceof FilesViewNodeInner ){
 											
-								}else{
-									
-									file_to_row_map.put( ds_file, tv_row );
-								}
-							}
-							
-							for ( Object o: to_select ){
-								
-								TableRowCore row = null;
-								
-								if ( o instanceof FilesViewTreeNode ){
-									
-									if ( o instanceof FilesViewNodeLeaf ){
+										FilesViewNodeInner node = (FilesViewNodeInner)ds_file;
 										
-										row = file_to_row_map.get( ((FilesViewNodeLeaf)o).getTarget());
+										if ( sel.contains( node.getUID() + 1000000000 )){
+											
+											selected_rows.add( tv_row );
+										}
+									}else{
+										
+										if ( sel.contains( ds_file.getIndex())){
+											
+											selected_rows.add( tv_row );
+										}
 									}
-								}else if ( o instanceof FilesViewNodeInner ){
-									
-								}else{
-									
-									row = file_to_row_map.get( o );
-								}
-								
-								if ( row != null ){
-							
-									selected_rows.add( row );
 								}
 							}
-							
+														
 							if ( !selected_rows.isEmpty()){
 								
 								tv.setSelectedRows( selected_rows.toArray( new TableRowCore[0]));
@@ -1706,10 +1863,35 @@ public class FilesView
 
 				char file_separator = File.separatorChar;
 
-				FilesViewNodeInner root = current_root = new FilesViewNodeInner( dm, dm.getDisplayName(), null );
+				int uid = 0;
+				
+				FilesViewNodeInner root = current_root = new FilesViewNodeInner( dm, uid, dm.getDisplayName(), "", null );
 
 				tree_file_map.clear();
 				
+				Map<Integer,Boolean>	expansion_state;
+				
+				synchronized( KEY_DM_TREE_STATE ){
+					
+					expansion_state = (Map<Integer,Boolean>)dm.getUserData( KEY_DM_TREE_STATE );
+					
+					if ( expansion_state == null ){
+						
+						expansion_state = new HashMap<>();
+						
+					}else{
+						
+						expansion_state = new HashMap<>( expansion_state );
+					}
+				}
+				
+				if ( expansion_state.containsKey( uid )){
+					
+					root.setExpanded( false );
+				}
+				
+				uid++;
+				
 				DiskManagerFileInfo files[] = dm.getDiskManagerFileInfoSet().getFiles();
 
 				for ( DiskManagerFileInfo file: files ){
@@ -1722,7 +1904,8 @@ public class FilesView
 
 					int	pos = 0;
 				
-
+					String subfolder = "";
+					
 					while( true ){
 
 						int p = path.indexOf( file_separator, pos );
@@ -1740,7 +1923,7 @@ public class FilesView
 							break;
 							
 						}else{
-
+									
 							bit = path.substring( pos, p );
 
 							pos = p+1;
@@ -1749,10 +1932,23 @@ public class FilesView
 
 							if ( n == null ){
 	
-								n = new FilesViewNodeInner( dm, bit, node );
+								n = new FilesViewNodeInner( dm, uid, bit, subfolder, node );
 	
+								if ( expansion_state.containsKey( uid )){
+									
+									n.setExpanded( false );
+								}
+								
+								uid++;
+								
 								node.addChild( n );
 							}
+							
+							if ( subfolder.isEmpty()){
+								subfolder = bit;
+							}else{
+								subfolder += file_separator + bit;
+							}
 							node = n;
 						}
 					}
@@ -1795,7 +1991,7 @@ public class FilesView
 				
 				wait_until_idle = force_refresh;
 				
-				current_root = new FilesViewNodeInner( null, MessageText.getString( "label.downloads" ), null );
+				current_root = new FilesViewNodeInner( null, -1,  MessageText.getString( "label.downloads" ), "", null );
 				
 				tree_file_map.clear();
 				
@@ -1804,15 +2000,40 @@ public class FilesView
 				tv.removeAllTableRows();
 
 				char file_separator = File.separatorChar;
-
+				
 				int num = 0;
 				
 				for ( DownloadManager dm: managers ){
 				
 					num++;
 					
-					FilesViewNodeInner root =  new FilesViewNodeInner( dm, "(" + num + ") " + dm.getDisplayName(), current_root );
+					int uid = 0;
+
+					FilesViewNodeInner root =  new FilesViewNodeInner( dm, uid, "(" + num + ") " + dm.getDisplayName(), "", current_root );
 	
+					Map<Integer,Boolean>	expansion_state;
+					
+					synchronized( KEY_DM_TREE_STATE ){
+						
+						expansion_state = (Map<Integer,Boolean>)dm.getUserData( KEY_DM_TREE_STATE );
+						
+						if ( expansion_state == null ){
+							
+							expansion_state = new HashMap<>();
+							
+						}else{
+							
+							expansion_state = new HashMap<>( expansion_state );
+						}
+					}
+					
+					if ( expansion_state.containsKey( uid )){
+						
+						root.setExpanded( false );
+					}
+					
+					uid++;
+					
 					current_root.addChild( root );
 					
 					DiskManagerFileInfo files[] = dm.getDiskManagerFileInfoSet().getFiles();
@@ -1827,7 +2048,8 @@ public class FilesView
 	
 						int	pos = 0;
 					
-	
+						String subfolder = "";
+						
 						while( true ){
 	
 							int p = path.indexOf( file_separator, pos );
@@ -1845,7 +2067,7 @@ public class FilesView
 								break;
 								
 							}else{
-	
+									
 								bit = path.substring( pos, p );
 	
 								pos = p+1;
@@ -1854,10 +2076,24 @@ public class FilesView
 	
 								if ( n == null ){
 		
-									n = new FilesViewNodeInner( dm, bit, node );
+									n = new FilesViewNodeInner( dm, uid, bit, subfolder, node );
 		
+									if ( expansion_state.containsKey( uid )){
+										
+										n.setExpanded( false );
+									}
+									
+									uid++;
+									
 									node.addChild( n );
 								}
+								
+								if ( subfolder.isEmpty()){
+									subfolder = bit;
+								}else{
+									subfolder += file_separator + bit;
+								}
+								
 								node = n;
 							}
 						}
@@ -1965,7 +2201,9 @@ public class FilesView
 		implements DiskManagerFileInfo, FilesViewTreeNode, TableRowSWTChildController
 	{
 		private final DownloadManager						dm;
-		private final String								name;
+		private final int									uid;
+		private final String								node_name;
+		private final String								node_path;
 		private final FilesViewNodeInner					parent;
 		private final Map<String,FilesViewTreeNode>			kids = new TreeMap<>( tree_comp );
 		
@@ -1977,12 +2215,22 @@ public class FilesView
 		private
 		FilesViewNodeInner(
 			DownloadManager			_dm,
-			String					_name,
+			int						_uid,
+			String					_node_name,
+			String					_node_path,
 			FilesViewNodeInner		_parent )
 		{
-			dm		= _dm;
-			name	= _name;
-			parent	= _parent;
+			dm			= _dm;
+			uid			= _uid;
+			node_name	= _node_name;
+			node_path	= _node_path;
+			parent		= _parent;
+		}
+		
+		protected int
+		getUID()
+		{
+			return( uid );
 		}
 		
 		@Override
@@ -2056,9 +2304,15 @@ public class FilesView
 		public String
 		getName()
 		{
-			return( name );
+			return( node_name );
 		}
 
+		protected String
+		getPath()
+		{
+			return( node_path );
+		}
+		
 		@Override
 		public boolean
 		isExpanded()
@@ -2380,7 +2634,7 @@ public class FilesView
 		public File
 		getFile( boolean follow_link )
 		{
-			return( new File( name ));
+			return( node_path.isEmpty()?new File(node_name):new File( node_path, node_name ));
 		}
 
 		@Override
