@@ -49,6 +49,8 @@ import com.biglybt.pif.ui.config.Parameter;
 public class ConfigSectionInterfaceDisplaySWT
 	extends ConfigSectionImpl
 {
+	public static final String REFID_SECTION_SIDEBAR = "section-sidebar";
+	public static final String REFID_SECTION_TOOLBAR = "section-toolbar";
 
 	public static final String SECTION_ID = "display";
 
@@ -245,7 +247,7 @@ public class ConfigSectionInterfaceDisplaySWT
 		ParameterGroupImpl pgToolbarItems = new ParameterGroupImpl(null,
 				listToolbarItems).setNumberOfColumns2(0);
 		add("pgToolbarItems", pgToolbarItems, listToolbar);
-
+		
 		// row 3
 
 		add(new BooleanParameterImpl("IconBar.start.stop.separate",
@@ -255,6 +257,8 @@ public class ConfigSectionInterfaceDisplaySWT
 				"MainWindow.menu.view.iconbar", listToolbar);
 		add(pgToolbar);
 
+		pgToolbar.setReferenceID( REFID_SECTION_TOOLBAR );
+
 		// Group: sidebar
 		/////////
 
@@ -350,8 +354,9 @@ public class ConfigSectionInterfaceDisplaySWT
 				add(compact, listSideBar);
 			}
 
-			add(new ParameterGroupImpl("v3.MainWindow.menu.view.sidebar",
-					listSideBar));
+			ParameterGroupImpl group = add(new ParameterGroupImpl("v3.MainWindow.menu.view.sidebar", listSideBar));
+			
+			group.setReferenceID( REFID_SECTION_SIDEBAR );
 		}
 
 		// Group: status bar
