@@ -72,7 +72,6 @@ import com.biglybt.ui.swt.views.skin.sidebar.SideBar;
 import com.biglybt.ui.swt.views.skin.sidebar.SideBarEntrySWT;
 import com.biglybt.ui.swt.views.utils.CategoryUIUtils;
 import com.biglybt.ui.swt.views.utils.TagUIUtils;
-
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.ui.UIInstance;
 import com.biglybt.pif.ui.UIManager;
@@ -2922,8 +2921,10 @@ public class SB_Transfers
 					synchronized (tag_listener_lock) {
 						int tt = tag_type.getTagType();
 						
-						if (	( tt != TagType.TT_DOWNLOAD_CATEGORY && tt != TagType.TT_DOWNLOAD_INTERNAL ) &&
-								tagTypeListener != null) {
+						if ( 	tt != TagType.TT_DOWNLOAD_CATEGORY &&
+								tt != TagType.TT_DOWNLOAD_INTERNAL &&
+								tt != TagType.TT_SWARM_TAG &&
+								tagTypeListener != null ){
 
 							tag_type.addTagTypeListener(tagTypeListener, true);
 						}
