@@ -29,10 +29,12 @@ import org.eclipse.swt.events.*;
 import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.layout.*;
 import org.eclipse.swt.widgets.*;
+import org.json.simple.JSONObject;
 
 import com.biglybt.core.CoreFactory;
 import com.biglybt.core.config.COConfigurationManager;
 import com.biglybt.core.config.ParameterListener;
+import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.util.*;
 import com.biglybt.ui.UIFunctions;
 import com.biglybt.ui.UIFunctionsManager;
@@ -59,8 +61,9 @@ import com.biglybt.ui.swt.utils.FontUtils;
 import com.biglybt.ui.swt.views.IViewAlwaysInitialize;
 import com.biglybt.ui.swt.views.QuickLinksView;
 import com.biglybt.ui.swt.views.ViewManagerSWT;
+import com.biglybt.ui.swt.views.configsections.ConfigSectionInterfaceDisplaySWT;
 import com.biglybt.ui.swt.views.skin.SkinnedDialog;
-
+import com.biglybt.util.JSONUtils;
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.PluginManager;
 import com.biglybt.pif.download.Download;
@@ -396,6 +399,15 @@ public class SideBar
 		}
 	}
 
+	public boolean
+	canPopoutEntry(
+		MdiEntry	entry )
+	{
+		SideBarEntrySWT sbe = (SideBarEntrySWT)entry;
+		
+		return( sbe.canBuildStandAlone());
+	}
+	
 	public boolean
 	popoutEntry(
 		MdiEntry	entry,
@@ -746,9 +758,8 @@ public class SideBar
 							SideBarEntrySWT entry = (SideBarEntrySWT) treeItem.getData("MdiEntry");
 							//System.out.println("PaintItem: " + event.item + ";" + event.index + ";" + event.detail + ";" + event.getBounds() + ";" + event.gc.getClipping());
 							if (entry != null) {
-								boolean selected = getCurrentEntry() == entry
-										&& entry.isSelectable();
-
+								boolean selected = getCurrentEntry() == entry;
+									
 								if (!selected) {
 									event.detail &= ~SWT.SELECTED;
 								} else {
@@ -837,7 +848,7 @@ public class SideBar
 								return;
 							}
 							SideBarEntrySWT entry = (SideBarEntrySWT) treeItem.getData("MdiEntry");
-							if (entry != null && entry.isSelectable()) {
+							if (entry != null ) {
 								Point cursorLocation = tree.toControl(event.display.getCursorLocation());
 								if (lastCloseAreaClicked != null && lastCloseAreaClicked.contains(cursorLocation.x, cursorLocation.y)) {
 									return;
@@ -986,15 +997,35 @@ public class SideBar
 								}
 
 								if ( treeItem.getItemCount() > 0) {
-									if (!entry.isSelectable() || event.x < 20) {
-										// Note: On Windows, user can expand row by clicking the invisible area where the OS twisty would be
-  									MdiEntry currentEntry = getCurrentEntry();
-										if (currentEntry != null && entry.getViewID().equals(
-												currentEntry.getParentID())) {
-											showEntryByID(SIDEBAR_SECTION_LIBRARY);
+									
+									Integer rhs = (Integer)treeItem.getData( "expandoRHS" );
+									
+									int limit=rhs==null?20:rhs;
+									
+									if ( event.x < limit) {
+										
+											// Note: On Windows, user can expand row by clicking the invisible area where the OS twisty would be
+										
+										MdiEntry currentEntry = getCurrentEntry();
+										
+										String collapsedID = entry.getViewID();
+										
+										while( currentEntry != null ){
+											
+											String parentID = currentEntry.getParentID();
+											
+											if ( collapsedID.equals( parentID )) {
+											
+												showEntryByID( collapsedID );
+												
+												break;
+											}
+											
+											currentEntry = getEntry( parentID );
 										}
-  									entry.setExpanded(!wasExpanded);
-  									wasExpanded = !wasExpanded;
+
+										entry.setExpanded(!wasExpanded);
+										wasExpanded = !wasExpanded;
 									}
 								}
 							}
@@ -1013,6 +1044,8 @@ public class SideBar
 									// don't trigger popout if double click is in close area or
 									// item has child and user is clicking in the expandy area 
 
+								boolean done = false;
+								
 								Point cursorLocation = tree.toControl(event.display.getCursorLocation());
 								
 								if ( lastCloseAreaClicked == null || !lastCloseAreaClicked.contains(cursorLocation.x, cursorLocation.y)){
@@ -1021,7 +1054,18 @@ public class SideBar
 									
 									if ( treeItem.getItemCount() == 0 || ( offset != null && event.x >= offset )){
 										
-										popoutEntry( entry, true );
+										if ( canPopoutEntry(entry)){
+										
+											done = popoutEntry( entry, true );
+										}
+									}
+								}
+								
+								if ( !done ){
+									
+									if ( treeItem.getItemCount() > 0 ){
+										
+										entry.setExpanded( !entry.isExpanded());
 									}
 								}
 							}
@@ -1037,21 +1081,29 @@ public class SideBar
 
 							break;
 						}
-
 						case SWT.Collapse: {
 							SideBarEntrySWT entry = (SideBarEntrySWT) treeItem.getData("MdiEntry");
 							
 							MdiEntry currentEntry = getCurrentEntry();
 							
-							if (currentEntry != null
-									&& entry.getViewID().equals(currentEntry.getParentID())) {
+							String collapsedID = entry.getViewID();
+							
+							while( currentEntry != null ){
 								
-								showEntryByID(SIDEBAR_SECTION_LIBRARY);
+								String parentID = currentEntry.getParentID();
+								
+								if ( collapsedID.equals( parentID )) {
+								
+									showEntryByID( collapsedID );
+									
+									break;
+								}
+								
+								currentEntry = getEntry( parentID );
 							}
 						
 							break;
 						}
-
 					}
 				} catch (Exception e) {
 					Debug.out(e);
@@ -1215,16 +1267,50 @@ public class SideBar
 	
 					int indent = END_INDENT ? tree.getClientArea().width - 1 : 0;
 					TreeItem treeItem = tree.getItem(new Point(indent, ptMouse.y));
-					if (treeItem == null) {
-						return;
+					if (treeItem != null) {
+					
+						entry = (SideBarEntrySWT) treeItem.getData("MdiEntry");
+					}else{
+						entry = null;
 					}
-					entry = (SideBarEntrySWT) treeItem.getData("MdiEntry");
 				} else {
-					entry = getCurrentEntry();
+					entry = getCurrentEntry(); 
 				}
 
-				fillMenu(menuTree, entry, "sidebar");
+				if ( entry != null ){
+				
+					fillMenu(menuTree, entry, "sidebar");
+				}
 
+				if ( entry == null || entry.getParentID() == null ){
+					
+					if ( menuTree.getItemCount() > 0 ){
+						
+						new org.eclipse.swt.widgets.MenuItem( menuTree, SWT.SEPARATOR );
+					}
+					
+					org.eclipse.swt.widgets.MenuItem mi = new org.eclipse.swt.widgets.MenuItem( menuTree, SWT.PUSH );
+					
+					mi.setText( MessageText.getString( "menu.sidebar.options" ));
+					
+					mi.addListener( SWT.Selection, (ev)->{
+						UIFunctions uif = UIFunctionsManager.getUIFunctions();
+
+						if ( uif != null ){
+
+							JSONObject args = new JSONObject();
+
+							args.put( "select", ConfigSectionInterfaceDisplaySWT.REFID_SECTION_SIDEBAR);
+							
+							String args_str = JSONUtils.encodeToJSON( args );
+							
+							uif.getMDI().showEntryByID(
+									MultipleDocumentInterface.SIDEBAR_SECTION_CONFIG,
+									ConfigSectionInterfaceDisplaySWT.SECTION_ID + args_str );
+						}
+					});
+				}
+				
 				if (menuTree.getItemCount() == 0) {
 					Utils.execSWTThreadLater(0, new AERunnable() {
 						@Override
@@ -1907,7 +1993,7 @@ public class SideBar
 			return;
 		}
 
-		if (newEntry == null || !newEntry.isSelectable()) {
+		if (newEntry == null  ){
 			return;
 		}
 
