@@ -52,8 +52,8 @@ import com.biglybt.pif.download.Download;
 import com.biglybt.pif.ui.menus.MenuManager;
 import com.biglybt.pif.ui.tables.*;
 
-public class TableViewSWT_Common
-	implements MouseListener, MouseMoveListener, SelectionListener, KeyListener
+public abstract class TableViewSWT_Common
+	implements MouseListener, MouseMoveListener, SelectionListener, KeyListener, MenuDetectListener
 {
 
 	TableViewSWT<?> tv;
@@ -109,6 +109,40 @@ public class TableViewSWT_Common
 			}
 		}
 	}
+	
+	public void 
+	menuDetected(
+		MenuDetectEvent e )
+	{
+		Composite comp = tv.getTableComposite();
+		
+		Point mapped = comp.getDisplay().map( null, comp, new Point( e.x, e.y ));
+		
+		TableColumnCore tc = tv.getTableColumnByOffset(mapped.x);
+		TableCellCore cell = tv.getTableCell( mapped.x, mapped.y );
+		
+		if ( tc != null && cell instanceof TableCellSWT ){
+			
+			TableCellMenuEvent event = new TableCellMenuEvent( cell, e );
+			
+			Rectangle clientArea = tv.getClientArea();
+						
+			event.x		= clientArea.x + mapped.x;
+			event.y		= mapped.y;
+			
+			tc.invokeCellMenuListeners( event );
+			
+			if ( !event.skipCoreFunctionality){
+				
+				cell.invokeMenuListeners(event);
+			}
+			
+			if ( event.skipCoreFunctionality ){
+					
+				e.doit = false;
+			}
+		}
+	}
 
 	private boolean
 	isInExpando(
@@ -279,7 +313,7 @@ public class TableViewSWT_Common
 
 	private TableCellMouseEvent createMouseEvent(TableCellCore cell, MouseEvent e,
 			int type, boolean allowOOB) {
-		TableCellMouseEvent event = new TableCellMouseEvent();
+		TableCellMouseEvent event = new TableCellMouseEvent( e );
 		event.cell = cell;
 		if (cell != null) {
 			event.row = cell.getTableRow();
@@ -309,7 +343,7 @@ public class TableViewSWT_Common
 
 	private TableRowMouseEvent createMouseEvent(TableRowSWT row, MouseEvent e,
 			int type, boolean allowOOB) {
-		TableCellMouseEvent event = new TableCellMouseEvent();
+		TableCellMouseEvent event = new TableCellMouseEvent( e );
 		event.row = row;
 		event.eventType = type;
 		event.button = e.button;
@@ -905,7 +939,7 @@ public class TableViewSWT_Common
 		boolean enable_items = selectedRows.length > 0;
 
 		TableContextMenuItem[] items = TableContextMenuManager.getInstance().getAllAsArray(
-				sMenuID);
+				Utils.getBaseViewID(sMenuID));
 
 		if (items.length > 0 || menu_items.length > 0) {
 			new org.eclipse.swt.widgets.MenuItem(menu, SWT.SEPARATOR);
@@ -988,6 +1022,12 @@ public class TableViewSWT_Common
 				}
 			}
 
+			final MenuItem itemSelectAll = new MenuItem(menu, SWT.PUSH);
+			Messages.setLanguageText(itemSelectAll, "Button.selectAll");
+			itemSelectAll.addListener(SWT.Selection, (ev)->{
+				tv.selectAll();
+			});
+			
 			if (tv.getSWTFilter() != null) {
 				final MenuItem itemFilter = new MenuItem(menu, SWT.PUSH);
 				Messages.setLanguageText(itemFilter, "MyTorrentsView.menu.filter");
@@ -998,6 +1038,18 @@ public class TableViewSWT_Common
 					}
 				});
 			}
+			
+			MenuItem itemChangeTable = new MenuItem(menu, SWT.PUSH);
+			Messages.setLanguageText(itemChangeTable,
+					"MyTorrentsView.menu.editTableColumns");
+			Utils.setMenuItemImage(itemChangeTable, "columns");
+
+			itemChangeTable.addListener(SWT.Selection, new Listener() {
+				@Override
+				public void handleEvent(Event e) {
+					showColumnEditor( column );
+				}
+			});
 		}
 	}
 
